[polly] r206026 - Remove OpenScop

Tobias Grosser tobias at grosser.es
Fri Apr 11 02:47:48 PDT 2014


Author: grosser
Date: Fri Apr 11 04:47:45 2014
New Revision: 206026

URL: http://llvm.org/viewvc/llvm-project?rev=206026&view=rev
Log:
Remove OpenScop

We only supported a very old version of OpenScop that was entirely different
to what OpenScop is today. To not confuse people, we remove this old and
unusable support. If anyone is interested to add OpenScop support back in,
the relevant patches are available in version control.

Removed:
    polly/trunk/cmake/FindOpenScop.cmake
    polly/trunk/lib/Exchange/OpenScopExporter.cpp
    polly/trunk/lib/Exchange/OpenScopImporter.cpp
Modified:
    polly/trunk/CMakeLists.txt
    polly/trunk/Makefile.config.in
    polly/trunk/autoconf/aclocal.m4
    polly/trunk/autoconf/configure.ac
    polly/trunk/configure
    polly/trunk/include/polly/Config/config.h.cmake
    polly/trunk/include/polly/Config/config.h.in
    polly/trunk/include/polly/LinkAllPasses.h
    polly/trunk/lib/CMakeLists.txt
    polly/trunk/lib/Exchange/ScopLib.cpp
    polly/trunk/lib/Makefile
    polly/trunk/www/documentation/passes.html
    polly/trunk/www/example_manual_matmul.html
    polly/trunk/www/index.html
    polly/trunk/www/todo.html

Modified: polly/trunk/CMakeLists.txt
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/CMakeLists.txt?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/CMakeLists.txt (original)
+++ polly/trunk/CMakeLists.txt Fri Apr 11 04:47:45 2014
@@ -111,14 +111,6 @@ if (POLLY_ENABLE_GPGPU_CODEGEN)
   set(GPU_CODEGEN TRUE)
 endif(POLLY_ENABLE_GPGPU_CODEGEN)
 
-option(POLLY_ENABLE_OPENSCOP "Enable Openscop library for scop import/export" ON)
-if (POLLY_ENABLE_OPENSCOP)
-  FIND_PACKAGE(OpenScop)
-  if(OPENSCOP_FOUND)
-    set(POLLY_LINK_LIBS ${POLLY_LINK_LIBS} ${OPENSCOP_LIBRARY})
-  endif(OPENSCOP_FOUND)
-endif(POLLY_ENABLE_OPENSCOP)
-
 option(POLLY_ENABLE_SCOPLIB "Enable SCoPLib library for scop import/export" ON)
 if (POLLY_ENABLE_SCOPLIB)
   FIND_PACKAGE(SCoPLib)
@@ -143,10 +135,6 @@ if (CUDALIB_FOUND)
   INCLUDE_DIRECTORIES( ${CUDALIB_INCLUDE_DIR} )
 endif(CUDALIB_FOUND)
 
-# Support OpenScop export/import if the library is available.
-if (OPENSCOP_FOUND)
-  INCLUDE_DIRECTORIES( ${OPENSCOP_INCLUDE_DIR} )
-endif(OPENSCOP_FOUND)
 if (SCOPLIB_FOUND)
   INCLUDE_DIRECTORIES( ${SCOPLIB_INCLUDE_DIR} )
 endif(SCOPLIB_FOUND)

Modified: polly/trunk/Makefile.config.in
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/Makefile.config.in?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/Makefile.config.in (original)
+++ polly/trunk/Makefile.config.in Fri Apr 11 04:47:45 2014
@@ -30,17 +30,16 @@ POLLY_CXXFLAGS += "-fno-rtti -fno-except
 
 PLUTO_FOUND := @pluto_found@
 CLOOG_FOUND := @cloog_found@
-OPENSCOP_FOUND := @openscop_found@
 SCOPLIB_FOUND := @scoplib_found@
 CUDALIB_FOUND := @cuda_found@
 
 # Set include directroys
 POLLY_INC :=  @gmp_inc@ @isl_inc@ \
-              @cloog_inc@ @openscop_inc@ @scoplib_inc@ @cuda_inc@\
+              @cloog_inc@ @scoplib_inc@ @cuda_inc@\
 	      @pluto_inc@ -I$(POLLY_SRC_ROOT)/lib/JSON/include
 
-POLLY_LD := @gmp_ld@ @isl_ld@ @cloog_ld@ @openscop_ld@ @scoplib_ld@ \
+POLLY_LD := @gmp_ld@ @isl_ld@ @cloog_ld@ @scoplib_ld@ \
             @scoplib_rpath@ @cuda_ld@ @pluto_ld@
 
-POLLY_LIB := @gmp_lib@ @isl_lib@ @cloog_lib@ @openscop_lib@ @scoplib_lib@ \
+POLLY_LIB := @gmp_lib@ @isl_lib@ @cloog_lib@ @scoplib_lib@ \
              @cuda_lib@ @pluto_lib@

Modified: polly/trunk/autoconf/aclocal.m4
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/autoconf/aclocal.m4?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/autoconf/aclocal.m4 (original)
+++ polly/trunk/autoconf/aclocal.m4 Fri Apr 11 04:47:45 2014
@@ -1,7 +1,8 @@
-# generated automatically by aclocal 1.11.1 -*- Autoconf -*-
+# generated automatically by aclocal 1.11.6 -*- Autoconf -*-
 
 # Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-# 2005, 2006, 2007, 2008, 2009  Free Software Foundation, Inc.
+# 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation,
+# Inc.
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
 # with or without modifications, as long as this notice is preserved.

Modified: polly/trunk/autoconf/configure.ac
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/autoconf/configure.ac?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/autoconf/configure.ac (original)
+++ polly/trunk/autoconf/configure.ac Fri Apr 11 04:47:45 2014
@@ -99,11 +99,6 @@ CXXFLAGS=$saved_CXXFLAGS
 AS_IF([test "x$pluto_found" = "xyes"],
   [AC_DEFINE([PLUTO_FOUND],[1],[Define if pluto found])])
 
-dnl Check that we have openscop.
-find_lib_and_headers([openscop], [openscop/scop.h], [openscop])
-AS_IF([test "x$openscop_found" = "xyes"],
-  [AC_DEFINE([OPENSCOP_FOUND],[1],[Define if openscop found])])
-
 dnl Check that we have scoplib.
 find_lib_and_headers([scoplib], [scoplib/scop.h], [scoplib])
 AS_IF([test "x$scoplib_found" = "xyes"],

Removed: polly/trunk/cmake/FindOpenScop.cmake
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/cmake/FindOpenScop.cmake?rev=206025&view=auto
==============================================================================
--- polly/trunk/cmake/FindOpenScop.cmake (original)
+++ polly/trunk/cmake/FindOpenScop.cmake (removed)
@@ -1,19 +0,0 @@
-FIND_PATH(OPENSCOP_INCLUDE_DIR openscop/scop.h)
-
-FIND_LIBRARY(OPENSCOP_LIBRARY NAMES openscop)
-
-IF (OPENSCOP_INCLUDE_DIR AND OPENSCOP_LIBRARY)
-  SET(OPENSCOP_FOUND TRUE)
-ENDIF (OPENSCOP_INCLUDE_DIR AND OPENSCOP_LIBRARY)
-
-
-IF (OPENSCOP_FOUND)
-  IF (NOT Isl_FIND_QUIETLY)
-    MESSAGE(STATUS "Found OpenScop: ${OPENSCOP_LIBRARY}")
-  ENDIF (NOT Isl_FIND_QUIETLY)
-ELSE (OPENSCOP_FOUND)
-  IF (Isl_FIND_REQUIRED)
-    MESSAGE(FATAL_ERROR "Could not find OpenScop")
-  ENDIF (Isl_FIND_REQUIRED)
-ENDIF (OPENSCOP_FOUND)
-

Modified: polly/trunk/configure
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/configure?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/configure (original)
+++ polly/trunk/configure Fri Apr 11 04:47:45 2014
@@ -1,13 +1,11 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.65 for Polly 0.01.
+# Generated by GNU Autoconf 2.69 for Polly 0.01.
 #
 # Report bugs to <polly-dev at googlegroups.com>.
 #
 #
-# Copyright (C) 1992, 1993, 1994, 1995, 1996, 1998, 1999, 2000, 2001,
-# 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation,
-# Inc.
+# Copyright (C) 1992-1996, 1998-2012 Free Software Foundation, Inc.
 #
 #
 # This configure script is free software; the Free Software Foundation
@@ -91,6 +89,7 @@ fi
 IFS=" ""	$as_nl"
 
 # Find who we are.  Look in the path if we contain no directory separator.
+as_myself=
 case $0 in #((
   *[\\/]* ) as_myself=$0 ;;
   *) as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
@@ -135,6 +134,31 @@ export LANGUAGE
 # CDPATH.
 (unset CDPATH) >/dev/null 2>&1 && unset CDPATH
 
+# Use a proper internal environment variable to ensure we don't fall
+  # into an infinite loop, continuously re-executing ourselves.
+  if test x"${_as_can_reexec}" != xno && test "x$CONFIG_SHELL" != x; then
+    _as_can_reexec=no; export _as_can_reexec;
+    # We cannot yet assume a decent shell, so we have to provide a
+# neutralization value for shells without unset; and this also
+# works around shells that cannot unset nonexistent variables.
+# Preserve -v and -x to the replacement shell.
+BASH_ENV=/dev/null
+ENV=/dev/null
+(unset BASH_ENV) >/dev/null 2>&1 && unset BASH_ENV ENV
+case $- in # ((((
+  *v*x* | *x*v* ) as_opts=-vx ;;
+  *v* ) as_opts=-v ;;
+  *x* ) as_opts=-x ;;
+  * ) as_opts= ;;
+esac
+exec $CONFIG_SHELL $as_opts "$as_myself" ${1+"$@"}
+# Admittedly, this is quite paranoid, since all the known shells bail
+# out after a failed `exec'.
+$as_echo "$0: could not re-execute with $CONFIG_SHELL" >&2
+as_fn_exit 255
+  fi
+  # We don't want this to propagate to other subprocesses.
+          { _as_can_reexec=; unset _as_can_reexec;}
 if test "x$CONFIG_SHELL" = x; then
   as_bourne_compatible="if test -n \"\${ZSH_VERSION+set}\" && (emulate sh) >/dev/null 2>&1; then :
   emulate sh
@@ -168,7 +192,8 @@ if ( set x; as_fn_ret_success y && test
 else
   exitcode=1; echo positional parameters were not saved.
 fi
-test x\$exitcode = x0 || exit 1"
+test x\$exitcode = x0 || exit 1
+test -x / || exit 1"
   as_suggested="  as_lineno_1=";as_suggested=$as_suggested$LINENO;as_suggested=$as_suggested" as_lineno_1a=\$LINENO
   as_lineno_2=";as_suggested=$as_suggested$LINENO;as_suggested=$as_suggested" as_lineno_2a=\$LINENO
   eval 'test \"x\$as_lineno_1'\$as_run'\" != \"x\$as_lineno_2'\$as_run'\" &&
@@ -212,14 +237,25 @@ IFS=$as_save_IFS
 
 
       if test "x$CONFIG_SHELL" != x; then :
-  # We cannot yet assume a decent shell, so we have to provide a
-	# neutralization value for shells without unset; and this also
-	# works around shells that cannot unset nonexistent variables.
-	BASH_ENV=/dev/null
-	ENV=/dev/null
-	(unset BASH_ENV) >/dev/null 2>&1 && unset BASH_ENV ENV
-	export CONFIG_SHELL
-	exec "$CONFIG_SHELL" "$as_myself" ${1+"$@"}
+  export CONFIG_SHELL
+             # We cannot yet assume a decent shell, so we have to provide a
+# neutralization value for shells without unset; and this also
+# works around shells that cannot unset nonexistent variables.
+# Preserve -v and -x to the replacement shell.
+BASH_ENV=/dev/null
+ENV=/dev/null
+(unset BASH_ENV) >/dev/null 2>&1 && unset BASH_ENV ENV
+case $- in # ((((
+  *v*x* | *x*v* ) as_opts=-vx ;;
+  *v* ) as_opts=-v ;;
+  *x* ) as_opts=-x ;;
+  * ) as_opts= ;;
+esac
+exec $CONFIG_SHELL $as_opts "$as_myself" ${1+"$@"}
+# Admittedly, this is quite paranoid, since all the known shells bail
+# out after a failed `exec'.
+$as_echo "$0: could not re-execute with $CONFIG_SHELL" >&2
+exit 255
 fi
 
     if test x$as_have_required = xno; then :
@@ -318,10 +354,18 @@ $as_echo X"$as_dir" |
       test -d "$as_dir" && break
     done
     test -z "$as_dirs" || eval "mkdir $as_dirs"
-  } || test -d "$as_dir" || as_fn_error "cannot create directory $as_dir"
+  } || test -d "$as_dir" || as_fn_error $? "cannot create directory $as_dir"
 
 
 } # as_fn_mkdir_p
+
+# as_fn_executable_p FILE
+# -----------------------
+# Test if FILE is an executable regular file.
+as_fn_executable_p ()
+{
+  test -f "$1" && test -x "$1"
+} # as_fn_executable_p
 # as_fn_append VAR VALUE
 # ----------------------
 # Append the text in VALUE to the end of the definition contained in VAR. Take
@@ -358,19 +402,19 @@ else
 fi # as_fn_arith
 
 
-# as_fn_error ERROR [LINENO LOG_FD]
-# ---------------------------------
+# as_fn_error STATUS ERROR [LINENO LOG_FD]
+# ----------------------------------------
 # Output "`basename $0`: error: ERROR" to stderr. If LINENO and LOG_FD are
 # provided, also output the error to LOG_FD, referencing LINENO. Then exit the
-# script with status $?, using 1 if that was 0.
+# script with STATUS, using 1 if that was 0.
 as_fn_error ()
 {
-  as_status=$?; test $as_status -eq 0 && as_status=1
-  if test "$3"; then
-    as_lineno=${as_lineno-"$2"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-    $as_echo "$as_me:${as_lineno-$LINENO}: error: $1" >&$3
+  as_status=$1; test $as_status -eq 0 && as_status=1
+  if test "$4"; then
+    as_lineno=${as_lineno-"$3"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
+    $as_echo "$as_me:${as_lineno-$LINENO}: error: $2" >&$4
   fi
-  $as_echo "$as_me: error: $1" >&2
+  $as_echo "$as_me: error: $2" >&2
   as_fn_exit $as_status
 } # as_fn_error
 
@@ -443,6 +487,10 @@ as_cr_alnum=$as_cr_Letters$as_cr_digits
   chmod +x "$as_me.lineno" ||
     { $as_echo "$as_me: error: cannot create $as_me.lineno; rerun with a POSIX shell" >&2; as_fn_exit 1; }
 
+  # If we had to re-execute with $CONFIG_SHELL, we're ensured to have
+  # already done that, so ensure we don't try to do so again and fall
+  # in an infinite loop.  This has already happened in practice.
+  _as_can_reexec=no; export _as_can_reexec
   # Don't try to exec as it changes $[0], causing all sort of problems
   # (the dirname of $[0] is not the place where we might find the
   # original and so on.  Autoconf is especially sensitive to this).
@@ -477,16 +525,16 @@ if (echo >conf$$.file) 2>/dev/null; then
     # ... but there are two gotchas:
     # 1) On MSYS, both `ln -s file dir' and `ln file dir' fail.
     # 2) DJGPP < 2.04 has no symlinks; `ln -s' creates a wrapper executable.
-    # In both cases, we have to default to `cp -p'.
+    # In both cases, we have to default to `cp -pR'.
     ln -s conf$$.file conf$$.dir 2>/dev/null && test ! -f conf$$.exe ||
-      as_ln_s='cp -p'
+      as_ln_s='cp -pR'
   elif ln conf$$.file conf$$ 2>/dev/null; then
     as_ln_s=ln
   else
-    as_ln_s='cp -p'
+    as_ln_s='cp -pR'
   fi
 else
-  as_ln_s='cp -p'
+  as_ln_s='cp -pR'
 fi
 rm -f conf$$ conf$$.exe conf$$.dir/conf$$.file conf$$.file
 rmdir conf$$.dir 2>/dev/null
@@ -498,28 +546,8 @@ else
   as_mkdir_p=false
 fi
 
-if test -x / >/dev/null 2>&1; then
-  as_test_x='test -x'
-else
-  if ls -dL / >/dev/null 2>&1; then
-    as_ls_L_option=L
-  else
-    as_ls_L_option=
-  fi
-  as_test_x='
-    eval sh -c '\''
-      if test -d "$1"; then
-	test -d "$1/.";
-      else
-	case $1 in #(
-	-*)set "./$1";;
-	esac;
-	case `ls -ld'$as_ls_L_option' "$1" 2>/dev/null` in #((
-	???[sx]*):;;*)false;;esac;fi
-    '\'' sh
-  '
-fi
-as_executable_p=$as_test_x
+as_test_x='test -x'
+as_executable_p=as_fn_executable_p
 
 # Sed expression to map a string onto a valid CPP name.
 as_tr_cpp="eval sed 'y%*$as_cr_letters%P$as_cr_LETTERS%;s%[^_$as_cr_alnum]%_%g'"
@@ -532,7 +560,7 @@ test -n "$DJDIR" || exec 7<&0 </dev/null
 exec 6>&1
 
 # Name of the host.
-# hostname on some systems (SVR3.2, Linux) returns a bogus exit status,
+# hostname on some systems (SVR3.2, old GNU/Linux) returns a bogus exit status,
 # so uname gets run too.
 ac_hostname=`(hostname || uname -n) 2>/dev/null | sed 1q`
 
@@ -568,10 +596,6 @@ scoplib_ld
 scoplib_lib
 scoplib_inc
 scoplib_found
-openscop_ld
-openscop_lib
-openscop_inc
-openscop_found
 pluto_ld
 pluto_lib
 pluto_inc
@@ -644,7 +668,6 @@ with_gmp
 with_isl
 with_cloog
 with_pluto
-with_openscop
 with_scoplib
 enable_polly_gpu_codegen
 with_cuda
@@ -720,8 +743,9 @@ do
   fi
 
   case $ac_option in
-  *=*)	ac_optarg=`expr "X$ac_option" : '[^=]*=\(.*\)'` ;;
-  *)	ac_optarg=yes ;;
+  *=?*) ac_optarg=`expr "X$ac_option" : '[^=]*=\(.*\)'` ;;
+  *=)   ac_optarg= ;;
+  *)    ac_optarg=yes ;;
   esac
 
   # Accept the important Cygnus configure options, so we can diagnose typos.
@@ -766,7 +790,7 @@ do
     ac_useropt=`expr "x$ac_option" : 'x-*disable-\(.*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error "invalid feature name: $ac_useropt"
+      as_fn_error $? "invalid feature name: $ac_useropt"
     ac_useropt_orig=$ac_useropt
     ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
@@ -792,7 +816,7 @@ do
     ac_useropt=`expr "x$ac_option" : 'x-*enable-\([^=]*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error "invalid feature name: $ac_useropt"
+      as_fn_error $? "invalid feature name: $ac_useropt"
     ac_useropt_orig=$ac_useropt
     ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
@@ -996,7 +1020,7 @@ do
     ac_useropt=`expr "x$ac_option" : 'x-*with-\([^=]*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error "invalid package name: $ac_useropt"
+      as_fn_error $? "invalid package name: $ac_useropt"
     ac_useropt_orig=$ac_useropt
     ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
@@ -1012,7 +1036,7 @@ do
     ac_useropt=`expr "x$ac_option" : 'x-*without-\(.*\)'`
     # Reject names that are not valid shell variable names.
     expr "x$ac_useropt" : ".*[^-+._$as_cr_alnum]" >/dev/null &&
-      as_fn_error "invalid package name: $ac_useropt"
+      as_fn_error $? "invalid package name: $ac_useropt"
     ac_useropt_orig=$ac_useropt
     ac_useropt=`$as_echo "$ac_useropt" | sed 's/[-+.]/_/g'`
     case $ac_user_opts in
@@ -1042,8 +1066,8 @@ do
   | --x-librar=* | --x-libra=* | --x-libr=* | --x-lib=* | --x-li=* | --x-l=*)
     x_libraries=$ac_optarg ;;
 
-  -*) as_fn_error "unrecognized option: \`$ac_option'
-Try \`$0 --help' for more information."
+  -*) as_fn_error $? "unrecognized option: \`$ac_option'
+Try \`$0 --help' for more information"
     ;;
 
   *=*)
@@ -1051,7 +1075,7 @@ Try \`$0 --help' for more information."
     # Reject names that are not valid shell variable names.
     case $ac_envvar in #(
       '' | [0-9]* | *[!_$as_cr_alnum]* )
-      as_fn_error "invalid variable name: \`$ac_envvar'" ;;
+      as_fn_error $? "invalid variable name: \`$ac_envvar'" ;;
     esac
     eval $ac_envvar=\$ac_optarg
     export $ac_envvar ;;
@@ -1061,7 +1085,7 @@ Try \`$0 --help' for more information."
     $as_echo "$as_me: WARNING: you should use --build, --host, --target" >&2
     expr "x$ac_option" : ".*[^-._$as_cr_alnum]" >/dev/null &&
       $as_echo "$as_me: WARNING: invalid host type: $ac_option" >&2
-    : ${build_alias=$ac_option} ${host_alias=$ac_option} ${target_alias=$ac_option}
+    : "${build_alias=$ac_option} ${host_alias=$ac_option} ${target_alias=$ac_option}"
     ;;
 
   esac
@@ -1069,13 +1093,13 @@ done
 
 if test -n "$ac_prev"; then
   ac_option=--`echo $ac_prev | sed 's/_/-/g'`
-  as_fn_error "missing argument to $ac_option"
+  as_fn_error $? "missing argument to $ac_option"
 fi
 
 if test -n "$ac_unrecognized_opts"; then
   case $enable_option_checking in
     no) ;;
-    fatal) as_fn_error "unrecognized options: $ac_unrecognized_opts" ;;
+    fatal) as_fn_error $? "unrecognized options: $ac_unrecognized_opts" ;;
     *)     $as_echo "$as_me: WARNING: unrecognized options: $ac_unrecognized_opts" >&2 ;;
   esac
 fi
@@ -1098,7 +1122,7 @@ do
     [\\/$]* | ?:[\\/]* )  continue;;
     NONE | '' ) case $ac_var in *prefix ) continue;; esac;;
   esac
-  as_fn_error "expected an absolute directory name for --$ac_var: $ac_val"
+  as_fn_error $? "expected an absolute directory name for --$ac_var: $ac_val"
 done
 
 # There might be people who depend on the old broken behavior: `$host'
@@ -1112,8 +1136,6 @@ target=$target_alias
 if test "x$host_alias" != x; then
   if test "x$build_alias" = x; then
     cross_compiling=maybe
-    $as_echo "$as_me: WARNING: If you wanted to set the --build type, don't use --host.
-    If a cross compiler is detected then cross compile mode will be used." >&2
   elif test "x$build_alias" != "x$host_alias"; then
     cross_compiling=yes
   fi
@@ -1128,9 +1150,9 @@ test "$silent" = yes && exec 6>/dev/null
 ac_pwd=`pwd` && test -n "$ac_pwd" &&
 ac_ls_di=`ls -di .` &&
 ac_pwd_ls_di=`cd "$ac_pwd" && ls -di .` ||
-  as_fn_error "working directory cannot be determined"
+  as_fn_error $? "working directory cannot be determined"
 test "X$ac_ls_di" = "X$ac_pwd_ls_di" ||
-  as_fn_error "pwd does not report name of working directory"
+  as_fn_error $? "pwd does not report name of working directory"
 
 
 # Find the source files, if location was not specified.
@@ -1169,11 +1191,11 @@ else
 fi
 if test ! -r "$srcdir/$ac_unique_file"; then
   test "$ac_srcdir_defaulted" = yes && srcdir="$ac_confdir or .."
-  as_fn_error "cannot find sources ($ac_unique_file) in $srcdir"
+  as_fn_error $? "cannot find sources ($ac_unique_file) in $srcdir"
 fi
 ac_msg="sources are in $srcdir, but \`cd $srcdir' does not work"
 ac_abs_confdir=`(
-	cd "$srcdir" && test -r "./$ac_unique_file" || as_fn_error "$ac_msg"
+	cd "$srcdir" && test -r "./$ac_unique_file" || as_fn_error $? "$ac_msg"
 	pwd)`
 # When building in place, set srcdir=.
 if test "$ac_abs_confdir" = "$ac_pwd"; then
@@ -1213,7 +1235,7 @@ Configuration:
       --help=short        display options specific to this package
       --help=recursive    display the short help of all the included packages
   -V, --version           display version information and exit
-  -q, --quiet, --silent   do not print \`checking...' messages
+  -q, --quiet, --silent   do not print \`checking ...' messages
       --cache-file=FILE   cache test results in FILE [disabled]
   -C, --config-cache      alias for \`--cache-file=config.cache'
   -n, --no-create         do not create output files
@@ -1280,7 +1302,6 @@ Optional Packages:
   --with-isl              prefix of isl
   --with-cloog            prefix of cloog
   --with-pluto            prefix of pluto
-  --with-openscop         prefix of openscop
   --with-scoplib          prefix of scoplib
   --with-cuda             prefix of cuda
 
@@ -1360,9 +1381,9 @@ test -n "$ac_init_help" && exit $ac_stat
 if $ac_init_version; then
   cat <<\_ACEOF
 Polly configure 0.01
-generated by GNU Autoconf 2.65
+generated by GNU Autoconf 2.69
 
-Copyright (C) 2009 Free Software Foundation, Inc.
+Copyright (C) 2012 Free Software Foundation, Inc.
 This configure script is free software; the Free Software Foundation
 gives unlimited permission to copy, distribute and modify it.
 _ACEOF
@@ -1406,7 +1427,7 @@ sed 's/^/| /' conftest.$ac_ext >&5
 
 	ac_retval=1
 fi
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
   as_fn_set_status $ac_retval
 
 } # ac_fn_cxx_try_compile
@@ -1438,7 +1459,7 @@ $as_echo "$ac_try_echo"; } >&5
 	 test ! -s conftest.err
        } && test -s conftest$ac_exeext && {
 	 test "$cross_compiling" = yes ||
-	 $as_test_x conftest$ac_exeext
+	 test -x conftest$ac_exeext
        }; then :
   ac_retval=0
 else
@@ -1452,7 +1473,7 @@ fi
   # interfere with the next link command; also delete a directory that is
   # left behind by Apple's compiler.  We do this before executing the actions.
   rm -rf conftest.dSYM conftest_ipa8_conftest.oo
-  eval $as_lineno_stack; test "x$as_lineno_stack" = x && { as_lineno=; unset as_lineno;}
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
   as_fn_set_status $ac_retval
 
 } # ac_fn_cxx_try_link
@@ -1461,7 +1482,7 @@ This file contains any messages produced
 running configure, to aid debugging if configure makes a mistake.
 
 It was created by Polly $as_me 0.01, which was
-generated by GNU Autoconf 2.65.  Invocation command line was
+generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
 
@@ -1571,11 +1592,9 @@ trap 'exit_status=$?
   {
     echo
 
-    cat <<\_ASBOX
-## ---------------- ##
+    $as_echo "## ---------------- ##
 ## Cache variables. ##
-## ---------------- ##
-_ASBOX
+## ---------------- ##"
     echo
     # The following way of writing the cache mishandles newlines in values,
 (
@@ -1609,11 +1628,9 @@ $as_echo "$as_me: WARNING: cache variabl
 )
     echo
 
-    cat <<\_ASBOX
-## ----------------- ##
+    $as_echo "## ----------------- ##
 ## Output variables. ##
-## ----------------- ##
-_ASBOX
+## ----------------- ##"
     echo
     for ac_var in $ac_subst_vars
     do
@@ -1626,11 +1643,9 @@ _ASBOX
     echo
 
     if test -n "$ac_subst_files"; then
-      cat <<\_ASBOX
-## ------------------- ##
+      $as_echo "## ------------------- ##
 ## File substitutions. ##
-## ------------------- ##
-_ASBOX
+## ------------------- ##"
       echo
       for ac_var in $ac_subst_files
       do
@@ -1644,11 +1659,9 @@ _ASBOX
     fi
 
     if test -s confdefs.h; then
-      cat <<\_ASBOX
-## ----------- ##
+      $as_echo "## ----------- ##
 ## confdefs.h. ##
-## ----------- ##
-_ASBOX
+## ----------- ##"
       echo
       cat confdefs.h
       echo
@@ -1703,7 +1716,12 @@ _ACEOF
 ac_site_file1=NONE
 ac_site_file2=NONE
 if test -n "$CONFIG_SITE"; then
-  ac_site_file1=$CONFIG_SITE
+  # We do not want a PATH search for config.site.
+  case $CONFIG_SITE in #((
+    -*)  ac_site_file1=./$CONFIG_SITE;;
+    */*) ac_site_file1=$CONFIG_SITE;;
+    *)   ac_site_file1=./$CONFIG_SITE;;
+  esac
 elif test "x$prefix" != xNONE; then
   ac_site_file1=$prefix/share/config.site
   ac_site_file2=$prefix/etc/config.site
@@ -1718,7 +1736,11 @@ do
     { $as_echo "$as_me:${as_lineno-$LINENO}: loading site script $ac_site_file" >&5
 $as_echo "$as_me: loading site script $ac_site_file" >&6;}
     sed 's/^/| /' "$ac_site_file" >&5
-    . "$ac_site_file"
+    . "$ac_site_file" \
+      || { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error $? "failed to load site script $ac_site_file
+See \`config.log' for more details" "$LINENO" 5; }
   fi
 done
 
@@ -1794,7 +1816,7 @@ if $ac_cache_corrupted; then
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
   { $as_echo "$as_me:${as_lineno-$LINENO}: error: changes in the environment can compromise the build" >&5
 $as_echo "$as_me: error: changes in the environment can compromise the build" >&2;}
-  as_fn_error "run \`make distclean' and/or \`rm $cache_file' and start over" "$LINENO" 5
+  as_fn_error $? "run \`make distclean' and/or \`rm $cache_file' and start over" "$LINENO" 5
 fi
 ## -------------------- ##
 ## Main body of script. ##
@@ -1837,16 +1859,22 @@ fi
 
 ac_aux_dir=
 for ac_dir in $LLVM_SRC/autoconf "$srcdir"/$LLVM_SRC/autoconf; do
-  for ac_t in install-sh install.sh shtool; do
-    if test -f "$ac_dir/$ac_t"; then
-      ac_aux_dir=$ac_dir
-      ac_install_sh="$ac_aux_dir/$ac_t -c"
-      break 2
-    fi
-  done
+  if test -f "$ac_dir/install-sh"; then
+    ac_aux_dir=$ac_dir
+    ac_install_sh="$ac_aux_dir/install-sh -c"
+    break
+  elif test -f "$ac_dir/install.sh"; then
+    ac_aux_dir=$ac_dir
+    ac_install_sh="$ac_aux_dir/install.sh -c"
+    break
+  elif test -f "$ac_dir/shtool"; then
+    ac_aux_dir=$ac_dir
+    ac_install_sh="$ac_aux_dir/shtool install -c"
+    break
+  fi
 done
 if test -z "$ac_aux_dir"; then
-  as_fn_error "cannot find install-sh, install.sh, or shtool in $LLVM_SRC/autoconf \"$srcdir\"/$LLVM_SRC/autoconf" "$LINENO" 5
+  as_fn_error $? "cannot find install-sh, install.sh, or shtool in $LLVM_SRC/autoconf \"$srcdir\"/$LLVM_SRC/autoconf" "$LINENO" 5
 fi
 
 # These three variables are undocumented and unsupported,
@@ -1871,7 +1899,7 @@ ac_config_files="$ac_config_files Makefi
 
 if test ${srcdir} != "." ; then
   if test -f ${srcdir}/include/polly/Config/config.h ; then
-    as_fn_error "Already configured in ${srcdir}" "$LINENO" 5
+    as_fn_error $? "Already configured in ${srcdir}" "$LINENO" 5
   fi
 fi
 
@@ -1903,7 +1931,7 @@ if test -z "$CXX"; then
 set dummy $ac_tool_prefix$ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_CXX+set}" = set; then :
+if ${ac_cv_prog_CXX+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$CXX"; then
@@ -1915,7 +1943,7 @@ do
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_CXX="$ac_tool_prefix$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -1947,7 +1975,7 @@ do
 set dummy $ac_prog; ac_word=$2
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
 $as_echo_n "checking for $ac_word... " >&6; }
-if test "${ac_cv_prog_ac_ct_CXX+set}" = set; then :
+if ${ac_cv_prog_ac_ct_CXX+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   if test -n "$ac_ct_CXX"; then
@@ -1959,7 +1987,7 @@ do
   IFS=$as_save_IFS
   test -z "$as_dir" && as_dir=.
     for ac_exec_ext in '' $ac_executable_extensions; do
-  if { test -f "$as_dir/$ac_word$ac_exec_ext" && $as_test_x "$as_dir/$ac_word$ac_exec_ext"; }; then
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
     ac_cv_prog_ac_ct_CXX="$ac_prog"
     $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
     break 2
@@ -2110,9 +2138,8 @@ sed 's/^/| /' conftest.$ac_ext >&5
 
 { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-{ as_fn_set_status 77
-as_fn_error "C++ compiler cannot create executables
-See \`config.log' for more details." "$LINENO" 5; }; }
+as_fn_error 77 "C++ compiler cannot create executables
+See \`config.log' for more details" "$LINENO" 5; }
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
 $as_echo "yes" >&6; }
@@ -2154,8 +2181,8 @@ done
 else
   { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error "cannot compute suffix of executables: cannot compile and link
-See \`config.log' for more details." "$LINENO" 5; }
+as_fn_error $? "cannot compute suffix of executables: cannot compile and link
+See \`config.log' for more details" "$LINENO" 5; }
 fi
 rm -f conftest conftest$ac_cv_exeext
 { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_exeext" >&5
@@ -2212,9 +2239,9 @@ $as_echo "$ac_try_echo"; } >&5
     else
 	{ { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error "cannot run C++ compiled programs.
+as_fn_error $? "cannot run C++ compiled programs.
 If you meant to cross compile, use \`--host'.
-See \`config.log' for more details." "$LINENO" 5; }
+See \`config.log' for more details" "$LINENO" 5; }
     fi
   fi
 fi
@@ -2225,7 +2252,7 @@ rm -f conftest.$ac_ext conftest$ac_cv_ex
 ac_clean_files=$ac_clean_files_save
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking for suffix of object files" >&5
 $as_echo_n "checking for suffix of object files... " >&6; }
-if test "${ac_cv_objext+set}" = set; then :
+if ${ac_cv_objext+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -2265,8 +2292,8 @@ sed 's/^/| /' conftest.$ac_ext >&5
 
 { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error "cannot compute suffix of object files: cannot compile
-See \`config.log' for more details." "$LINENO" 5; }
+as_fn_error $? "cannot compute suffix of object files: cannot compile
+See \`config.log' for more details" "$LINENO" 5; }
 fi
 rm -f conftest.$ac_cv_objext conftest.$ac_ext
 fi
@@ -2276,7 +2303,7 @@ OBJEXT=$ac_cv_objext
 ac_objext=$OBJEXT
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are using the GNU C++ compiler" >&5
 $as_echo_n "checking whether we are using the GNU C++ compiler... " >&6; }
-if test "${ac_cv_cxx_compiler_gnu+set}" = set; then :
+if ${ac_cv_cxx_compiler_gnu+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
@@ -2313,7 +2340,7 @@ ac_test_CXXFLAGS=${CXXFLAGS+set}
 ac_save_CXXFLAGS=$CXXFLAGS
 { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CXX accepts -g" >&5
 $as_echo_n "checking whether $CXX accepts -g... " >&6; }
-if test "${ac_cv_prog_cxx_g+set}" = set; then :
+if ${ac_cv_prog_cxx_g+:} false; then :
   $as_echo_n "(cached) " >&6
 else
   ac_save_cxx_werror_flag=$ac_cxx_werror_flag
@@ -2454,7 +2481,7 @@ fi
 fi
 else
   if test "x" = "xrequired"; then :
-  as_fn_error "gmp required but not found" "$LINENO" 5
+  as_fn_error $? "gmp required but not found" "$LINENO" 5
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: not found" >&5
 $as_echo "not found" >&6; }
@@ -2536,7 +2563,7 @@ fi
 fi
 else
   if test "xrequired" = "xrequired"; then :
-  as_fn_error "isl required but not found" "$LINENO" 5
+  as_fn_error $? "isl required but not found" "$LINENO" 5
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: not found" >&5
 $as_echo "not found" >&6; }
@@ -2619,7 +2646,7 @@ fi
 fi
 else
   if test "x" = "xrequired"; then :
-  as_fn_error "cloog required but not found" "$LINENO" 5
+  as_fn_error $? "cloog required but not found" "$LINENO" 5
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: not found" >&5
 $as_echo "not found" >&6; }
@@ -2707,7 +2734,7 @@ fi
 fi
 else
   if test "x" = "xrequired"; then :
-  as_fn_error "pluto required but not found" "$LINENO" 5
+  as_fn_error $? "pluto required but not found" "$LINENO" 5
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: not found" >&5
 $as_echo "not found" >&6; }
@@ -2746,91 +2773,6 @@ ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
   OLD_LDFLAGS=$LDFLAGS;
   OLD_LIBS=$LIBS;
 
-  LIBS="$LIBS -lopenscop";
-
-  # Get include path and lib path
-
-# Check whether --with-openscop was given.
-if test "${with_openscop+set}" = set; then :
-  withval=$with_openscop; given_inc_path="$withval/include"; CXXFLAGS="-I$given_inc_path $CXXFLAGS";
-       given_lib_path="$withval/lib"; LDFLAGS="-L$given_lib_path $LDFLAGS"
-else
-  given_inc_path=inc_not_give_openscop;
-       given_lib_path=lib_not_give_openscop
-
-fi
-
-  # Check for library and headers works
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for openscop: openscop/scop.h in $given_inc_path, and libopenscop in $given_lib_path" >&5
-$as_echo_n "checking for openscop: openscop/scop.h in $given_inc_path, and libopenscop in $given_lib_path... " >&6; }
-
-  # try to compile a file that includes a header of the library
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <openscop/scop.h>
-int
-main ()
-{
-;
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_cxx_try_link "$LINENO"; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: ok" >&5
-$as_echo "ok" >&6; }
-    openscop_found="yes"
-
-    if test "x$given_inc_path" != "xinc_not_give_openscop"; then :
-  openscop_inc="-I$given_inc_path"
-
-fi
-    openscop_lib="-lopenscop"
-
-    if test "x$given_lib_path" != "xlib_not_give_openscop"; then :
-  openscop_ld="-L$given_lib_path"
-
-fi
-else
-  if test "x" = "xrequired"; then :
-  as_fn_error "openscop required but not found" "$LINENO" 5
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: not found" >&5
-$as_echo "not found" >&6; }
-fi
-
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-
-  # reset original CXXFLAGS
-  CXXFLAGS=$OLD_CXXFLAGS
-  LDFLAGS=$OLD_LDFLAGS;
-  LIBS=$OLD_LIBS
-  ac_ext=c
-ac_cpp='$CPP $CPPFLAGS'
-ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
-ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
-
-
-if test "x$openscop_found" = "xyes"; then :
-
-$as_echo "#define OPENSCOP_FOUND 1" >>confdefs.h
-
-fi
-
-
-  ac_ext=cpp
-ac_cpp='$CXXCPP $CPPFLAGS'
-ac_compile='$CXX -c $CXXFLAGS $CPPFLAGS conftest.$ac_ext >&5'
-ac_link='$CXX -o conftest$ac_exeext $CXXFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_cxx_compiler_gnu
-
-  OLD_CXXFLAGS=$CXXFLAGS;
-  OLD_LDFLAGS=$LDFLAGS;
-  OLD_LIBS=$LIBS;
-
   LIBS="$LIBS -lscoplib";
 
   # Get include path and lib path
@@ -2878,7 +2820,7 @@ fi
 fi
 else
   if test "x" = "xrequired"; then :
-  as_fn_error "scoplib required but not found" "$LINENO" 5
+  as_fn_error $? "scoplib required but not found" "$LINENO" 5
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: not found" >&5
 $as_echo "not found" >&6; }
@@ -2926,7 +2868,7 @@ $as_echo "#define GPU_CODEGEN 1" >>confd
  ;;
   no) ;;
   default) ;;
-  *) as_fn_error "Invalid setting for --enable-polly-gpu-codegen. Use \"yes\" or \"no\"" "$LINENO" 5 ;;
+  *) as_fn_error $? "Invalid setting for --enable-polly-gpu-codegen. Use \"yes\" or \"no\"" "$LINENO" 5 ;;
 esac
 
 
@@ -2987,7 +2929,7 @@ fi
 fi
 else
   if test "x" = "xrequired"; then :
-  as_fn_error "cuda required but not found" "$LINENO" 5
+  as_fn_error $? "cuda required but not found" "$LINENO" 5
 else
   { $as_echo "$as_me:${as_lineno-$LINENO}: result: not found" >&5
 $as_echo "not found" >&6; }
@@ -3082,10 +3024,21 @@ $as_echo "$as_me: WARNING: cache variabl
      :end' >>confcache
 if diff "$cache_file" confcache >/dev/null 2>&1; then :; else
   if test -w "$cache_file"; then
-    test "x$cache_file" != "x/dev/null" &&
+    if test "x$cache_file" != "x/dev/null"; then
       { $as_echo "$as_me:${as_lineno-$LINENO}: updating cache $cache_file" >&5
 $as_echo "$as_me: updating cache $cache_file" >&6;}
-    cat confcache >$cache_file
+      if test ! -f "$cache_file" || test -h "$cache_file"; then
+	cat confcache >"$cache_file"
+      else
+        case $cache_file in #(
+        */* | ?:*)
+	  mv -f confcache "$cache_file"$$ &&
+	  mv -f "$cache_file"$$ "$cache_file" ;; #(
+        *)
+	  mv -f confcache "$cache_file" ;;
+	esac
+      fi
+    fi
   else
     { $as_echo "$as_me:${as_lineno-$LINENO}: not updating unwritable cache $cache_file" >&5
 $as_echo "$as_me: not updating unwritable cache $cache_file" >&6;}
@@ -3101,6 +3054,7 @@ DEFS=-DHAVE_CONFIG_H
 
 ac_libobjs=
 ac_ltlibobjs=
+U=
 for ac_i in : $LIBOBJS; do test "x$ac_i" = x: && continue
   # 1. Remove the extension, and $U if already installed.
   ac_script='s/\$U\././;s/\.o$//;s/\.obj$//'
@@ -3116,7 +3070,7 @@ LTLIBOBJS=$ac_ltlibobjs
 
 
 
-: ${CONFIG_STATUS=./config.status}
+: "${CONFIG_STATUS=./config.status}"
 ac_write_fail=0
 ac_clean_files_save=$ac_clean_files
 ac_clean_files="$ac_clean_files $CONFIG_STATUS"
@@ -3217,6 +3171,7 @@ fi
 IFS=" ""	$as_nl"
 
 # Find who we are.  Look in the path if we contain no directory separator.
+as_myself=
 case $0 in #((
   *[\\/]* ) as_myself=$0 ;;
   *) as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
@@ -3262,19 +3217,19 @@ export LANGUAGE
 (unset CDPATH) >/dev/null 2>&1 && unset CDPATH
 
 
-# as_fn_error ERROR [LINENO LOG_FD]
-# ---------------------------------
+# as_fn_error STATUS ERROR [LINENO LOG_FD]
+# ----------------------------------------
 # Output "`basename $0`: error: ERROR" to stderr. If LINENO and LOG_FD are
 # provided, also output the error to LOG_FD, referencing LINENO. Then exit the
-# script with status $?, using 1 if that was 0.
+# script with STATUS, using 1 if that was 0.
 as_fn_error ()
 {
-  as_status=$?; test $as_status -eq 0 && as_status=1
-  if test "$3"; then
-    as_lineno=${as_lineno-"$2"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-    $as_echo "$as_me:${as_lineno-$LINENO}: error: $1" >&$3
+  as_status=$1; test $as_status -eq 0 && as_status=1
+  if test "$4"; then
+    as_lineno=${as_lineno-"$3"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
+    $as_echo "$as_me:${as_lineno-$LINENO}: error: $2" >&$4
   fi
-  $as_echo "$as_me: error: $1" >&2
+  $as_echo "$as_me: error: $2" >&2
   as_fn_exit $as_status
 } # as_fn_error
 
@@ -3412,16 +3367,16 @@ if (echo >conf$$.file) 2>/dev/null; then
     # ... but there are two gotchas:
     # 1) On MSYS, both `ln -s file dir' and `ln file dir' fail.
     # 2) DJGPP < 2.04 has no symlinks; `ln -s' creates a wrapper executable.
-    # In both cases, we have to default to `cp -p'.
+    # In both cases, we have to default to `cp -pR'.
     ln -s conf$$.file conf$$.dir 2>/dev/null && test ! -f conf$$.exe ||
-      as_ln_s='cp -p'
+      as_ln_s='cp -pR'
   elif ln conf$$.file conf$$ 2>/dev/null; then
     as_ln_s=ln
   else
-    as_ln_s='cp -p'
+    as_ln_s='cp -pR'
   fi
 else
-  as_ln_s='cp -p'
+  as_ln_s='cp -pR'
 fi
 rm -f conf$$ conf$$.exe conf$$.dir/conf$$.file conf$$.file
 rmdir conf$$.dir 2>/dev/null
@@ -3470,7 +3425,7 @@ $as_echo X"$as_dir" |
       test -d "$as_dir" && break
     done
     test -z "$as_dirs" || eval "mkdir $as_dirs"
-  } || test -d "$as_dir" || as_fn_error "cannot create directory $as_dir"
+  } || test -d "$as_dir" || as_fn_error $? "cannot create directory $as_dir"
 
 
 } # as_fn_mkdir_p
@@ -3481,28 +3436,16 @@ else
   as_mkdir_p=false
 fi
 
-if test -x / >/dev/null 2>&1; then
-  as_test_x='test -x'
-else
-  if ls -dL / >/dev/null 2>&1; then
-    as_ls_L_option=L
-  else
-    as_ls_L_option=
-  fi
-  as_test_x='
-    eval sh -c '\''
-      if test -d "$1"; then
-	test -d "$1/.";
-      else
-	case $1 in #(
-	-*)set "./$1";;
-	esac;
-	case `ls -ld'$as_ls_L_option' "$1" 2>/dev/null` in #((
-	???[sx]*):;;*)false;;esac;fi
-    '\'' sh
-  '
-fi
-as_executable_p=$as_test_x
+
+# as_fn_executable_p FILE
+# -----------------------
+# Test if FILE is an executable regular file.
+as_fn_executable_p ()
+{
+  test -f "$1" && test -x "$1"
+} # as_fn_executable_p
+as_test_x='test -x'
+as_executable_p=as_fn_executable_p
 
 # Sed expression to map a string onto a valid CPP name.
 as_tr_cpp="eval sed 'y%*$as_cr_letters%P$as_cr_LETTERS%;s%[^_$as_cr_alnum]%_%g'"
@@ -3524,7 +3467,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_wri
 # values after options handling.
 ac_log="
 This file was extended by Polly $as_me 0.01, which was
-generated by GNU Autoconf 2.65.  Invocation command line was
+generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
   CONFIG_HEADERS  = $CONFIG_HEADERS
@@ -3590,10 +3533,10 @@ cat >>$CONFIG_STATUS <<_ACEOF || ac_writ
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
 Polly config.status 0.01
-configured by $0, generated by GNU Autoconf 2.65,
+configured by $0, generated by GNU Autoconf 2.69,
   with options \\"\$ac_cs_config\\"
 
-Copyright (C) 2009 Free Software Foundation, Inc.
+Copyright (C) 2012 Free Software Foundation, Inc.
 This config.status script is free software; the Free Software Foundation
 gives unlimited permission to copy, distribute and modify it."
 
@@ -3608,11 +3551,16 @@ ac_need_defaults=:
 while test $# != 0
 do
   case $1 in
-  --*=*)
+  --*=?*)
     ac_option=`expr "X$1" : 'X\([^=]*\)='`
     ac_optarg=`expr "X$1" : 'X[^=]*=\(.*\)'`
     ac_shift=:
     ;;
+  --*=)
+    ac_option=`expr "X$1" : 'X\([^=]*\)='`
+    ac_optarg=
+    ac_shift=:
+    ;;
   *)
     ac_option=$1
     ac_optarg=$2
@@ -3634,6 +3582,7 @@ do
     $ac_shift
     case $ac_optarg in
     *\'*) ac_optarg=`$as_echo "$ac_optarg" | sed "s/'/'\\\\\\\\''/g"` ;;
+    '') as_fn_error $? "missing file argument" ;;
     esac
     as_fn_append CONFIG_FILES " '$ac_optarg'"
     ac_need_defaults=false;;
@@ -3646,7 +3595,7 @@ do
     ac_need_defaults=false;;
   --he | --h)
     # Conflict between --help and --header
-    as_fn_error "ambiguous option: \`$1'
+    as_fn_error $? "ambiguous option: \`$1'
 Try \`$0 --help' for more information.";;
   --help | --hel | -h )
     $as_echo "$ac_cs_usage"; exit ;;
@@ -3655,7 +3604,7 @@ Try \`$0 --help' for more information.";
     ac_cs_silent=: ;;
 
   # This is an error.
-  -*) as_fn_error "unrecognized option: \`$1'
+  -*) as_fn_error $? "unrecognized option: \`$1'
 Try \`$0 --help' for more information." ;;
 
   *) as_fn_append ac_config_targets " $1"
@@ -3675,7 +3624,7 @@ fi
 _ACEOF
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 if \$ac_cs_recheck; then
-  set X '$SHELL' '$0' $ac_configure_args \$ac_configure_extra_args --no-create --no-recursion
+  set X $SHELL '$0' $ac_configure_args \$ac_configure_extra_args --no-create --no-recursion
   shift
   \$as_echo "running CONFIG_SHELL=$SHELL \$*" >&6
   CONFIG_SHELL='$SHELL'
@@ -3714,7 +3663,7 @@ do
     "Makefile.common") CONFIG_FILES="$CONFIG_FILES Makefile.common" ;;
     "include/polly/Config/config.h") CONFIG_HEADERS="$CONFIG_HEADERS include/polly/Config/config.h" ;;
 
-  *) as_fn_error "invalid argument: \`$ac_config_target'" "$LINENO" 5;;
+  *) as_fn_error $? "invalid argument: \`$ac_config_target'" "$LINENO" 5;;
   esac
 done
 
@@ -3737,9 +3686,10 @@ fi
 # after its creation but before its name has been assigned to `$tmp'.
 $debug ||
 {
-  tmp=
+  tmp= ac_tmp=
   trap 'exit_status=$?
-  { test -z "$tmp" || test ! -d "$tmp" || rm -fr "$tmp"; } && exit $exit_status
+  : "${ac_tmp:=$tmp}"
+  { test ! -d "$ac_tmp" || rm -fr "$ac_tmp"; } && exit $exit_status
 ' 0
   trap 'as_fn_exit 1' 1 2 13 15
 }
@@ -3747,12 +3697,13 @@ $debug ||
 
 {
   tmp=`(umask 077 && mktemp -d "./confXXXXXX") 2>/dev/null` &&
-  test -n "$tmp" && test -d "$tmp"
+  test -d "$tmp"
 }  ||
 {
   tmp=./conf$$-$RANDOM
   (umask 077 && mkdir "$tmp")
-} || as_fn_error "cannot create a temporary directory in ." "$LINENO" 5
+} || as_fn_error $? "cannot create a temporary directory in ." "$LINENO" 5
+ac_tmp=$tmp
 
 # Set up the scripts for CONFIG_FILES section.
 # No need to generate them if there are no CONFIG_FILES.
@@ -3769,12 +3720,12 @@ if test "x$ac_cr" = x; then
 fi
 ac_cs_awk_cr=`$AWK 'BEGIN { print "a\rb" }' </dev/null 2>/dev/null`
 if test "$ac_cs_awk_cr" = "a${ac_cr}b"; then
-  ac_cs_awk_cr='\r'
+  ac_cs_awk_cr='\\r'
 else
   ac_cs_awk_cr=$ac_cr
 fi
 
-echo 'BEGIN {' >"$tmp/subs1.awk" &&
+echo 'BEGIN {' >"$ac_tmp/subs1.awk" &&
 _ACEOF
 
 
@@ -3783,18 +3734,18 @@ _ACEOF
   echo "$ac_subst_vars" | sed 's/.*/&!$&$ac_delim/' &&
   echo "_ACEOF"
 } >conf$$subs.sh ||
-  as_fn_error "could not make $CONFIG_STATUS" "$LINENO" 5
-ac_delim_num=`echo "$ac_subst_vars" | grep -c '$'`
+  as_fn_error $? "could not make $CONFIG_STATUS" "$LINENO" 5
+ac_delim_num=`echo "$ac_subst_vars" | grep -c '^'`
 ac_delim='%!_!# '
 for ac_last_try in false false false false false :; do
   . ./conf$$subs.sh ||
-    as_fn_error "could not make $CONFIG_STATUS" "$LINENO" 5
+    as_fn_error $? "could not make $CONFIG_STATUS" "$LINENO" 5
 
   ac_delim_n=`sed -n "s/.*$ac_delim\$/X/p" conf$$subs.awk | grep -c X`
   if test $ac_delim_n = $ac_delim_num; then
     break
   elif $ac_last_try; then
-    as_fn_error "could not make $CONFIG_STATUS" "$LINENO" 5
+    as_fn_error $? "could not make $CONFIG_STATUS" "$LINENO" 5
   else
     ac_delim="$ac_delim!$ac_delim _$ac_delim!! "
   fi
@@ -3802,7 +3753,7 @@ done
 rm -f conf$$subs.sh
 
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
-cat >>"\$tmp/subs1.awk" <<\\_ACAWK &&
+cat >>"\$ac_tmp/subs1.awk" <<\\_ACAWK &&
 _ACEOF
 sed -n '
 h
@@ -3850,7 +3801,7 @@ t delim
 rm -f conf$$subs.awk
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 _ACAWK
-cat >>"\$tmp/subs1.awk" <<_ACAWK &&
+cat >>"\$ac_tmp/subs1.awk" <<_ACAWK &&
   for (key in S) S_is_set[key] = 1
   FS = ""
 
@@ -3882,21 +3833,29 @@ if sed "s/$ac_cr//" < /dev/null > /dev/n
   sed "s/$ac_cr\$//; s/$ac_cr/$ac_cs_awk_cr/g"
 else
   cat
-fi < "$tmp/subs1.awk" > "$tmp/subs.awk" \
-  || as_fn_error "could not setup config files machinery" "$LINENO" 5
+fi < "$ac_tmp/subs1.awk" > "$ac_tmp/subs.awk" \
+  || as_fn_error $? "could not setup config files machinery" "$LINENO" 5
 _ACEOF
 
-# VPATH may cause trouble with some makes, so we remove $(srcdir),
-# ${srcdir} and @srcdir@ from VPATH if srcdir is ".", strip leading and
+# VPATH may cause trouble with some makes, so we remove sole $(srcdir),
+# ${srcdir} and @srcdir@ entries from VPATH if srcdir is ".", strip leading and
 # trailing colons and then remove the whole line if VPATH becomes empty
 # (actually we leave an empty line to preserve line numbers).
 if test "x$srcdir" = x.; then
-  ac_vpsub='/^[	 ]*VPATH[	 ]*=/{
-s/:*\$(srcdir):*/:/
-s/:*\${srcdir}:*/:/
-s/:*@srcdir@:*/:/
-s/^\([^=]*=[	 ]*\):*/\1/
+  ac_vpsub='/^[	 ]*VPATH[	 ]*=[	 ]*/{
+h
+s///
+s/^/:/
+s/[	 ]*$/:/
+s/:\$(srcdir):/:/g
+s/:\${srcdir}:/:/g
+s/:@srcdir@:/:/g
+s/^:*//
 s/:*$//
+x
+s/\(=[	 ]*\).*/\1/
+G
+s/\n//
 s/^[^=]*=[	 ]*$//
 }'
 fi
@@ -3908,7 +3867,7 @@ fi # test -n "$CONFIG_FILES"
 # No need to generate them if there are no CONFIG_HEADERS.
 # This happens for instance with `./config.status Makefile'.
 if test -n "$CONFIG_HEADERS"; then
-cat >"$tmp/defines.awk" <<\_ACAWK ||
+cat >"$ac_tmp/defines.awk" <<\_ACAWK ||
 BEGIN {
 _ACEOF
 
@@ -3920,11 +3879,11 @@ _ACEOF
 # handling of long lines.
 ac_delim='%!_!# '
 for ac_last_try in false false :; do
-  ac_t=`sed -n "/$ac_delim/p" confdefs.h`
-  if test -z "$ac_t"; then
+  ac_tt=`sed -n "/$ac_delim/p" confdefs.h`
+  if test -z "$ac_tt"; then
     break
   elif $ac_last_try; then
-    as_fn_error "could not make $CONFIG_HEADERS" "$LINENO" 5
+    as_fn_error $? "could not make $CONFIG_HEADERS" "$LINENO" 5
   else
     ac_delim="$ac_delim!$ac_delim _$ac_delim!! "
   fi
@@ -4009,7 +3968,7 @@ cat >>$CONFIG_STATUS <<_ACEOF || ac_writ
 _ACAWK
 _ACEOF
 cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
-  as_fn_error "could not setup config headers machinery" "$LINENO" 5
+  as_fn_error $? "could not setup config headers machinery" "$LINENO" 5
 fi # test -n "$CONFIG_HEADERS"
 
 
@@ -4022,7 +3981,7 @@ do
   esac
   case $ac_mode$ac_tag in
   :[FHL]*:*);;
-  :L* | :C*:*) as_fn_error "invalid tag \`$ac_tag'" "$LINENO" 5;;
+  :L* | :C*:*) as_fn_error $? "invalid tag \`$ac_tag'" "$LINENO" 5;;
   :[FH]-) ac_tag=-:-;;
   :[FH]*) ac_tag=$ac_tag:$ac_tag.in;;
   esac
@@ -4041,7 +4000,7 @@ do
     for ac_f
     do
       case $ac_f in
-      -) ac_f="$tmp/stdin";;
+      -) ac_f="$ac_tmp/stdin";;
       *) # Look for the file first in the build tree, then in the source tree
 	 # (if the path is not absolute).  The absolute path cannot be DOS-style,
 	 # because $ac_f cannot contain `:'.
@@ -4050,7 +4009,7 @@ do
 	   [\\/$]*) false;;
 	   *) test -f "$srcdir/$ac_f" && ac_f="$srcdir/$ac_f";;
 	   esac ||
-	   as_fn_error "cannot find input file: \`$ac_f'" "$LINENO" 5;;
+	   as_fn_error 1 "cannot find input file: \`$ac_f'" "$LINENO" 5;;
       esac
       case $ac_f in *\'*) ac_f=`$as_echo "$ac_f" | sed "s/'/'\\\\\\\\''/g"`;; esac
       as_fn_append ac_file_inputs " '$ac_f'"
@@ -4076,8 +4035,8 @@ $as_echo "$as_me: creating $ac_file" >&6
     esac
 
     case $ac_tag in
-    *:-:* | *:-) cat >"$tmp/stdin" \
-      || as_fn_error "could not create $ac_file" "$LINENO" 5 ;;
+    *:-:* | *:-) cat >"$ac_tmp/stdin" \
+      || as_fn_error $? "could not create $ac_file" "$LINENO" 5 ;;
     esac
     ;;
   esac
@@ -4202,23 +4161,24 @@ s&@abs_builddir@&$ac_abs_builddir&;t t
 s&@abs_top_builddir@&$ac_abs_top_builddir&;t t
 $ac_datarootdir_hack
 "
-eval sed \"\$ac_sed_extra\" "$ac_file_inputs" | $AWK -f "$tmp/subs.awk" >$tmp/out \
-  || as_fn_error "could not create $ac_file" "$LINENO" 5
+eval sed \"\$ac_sed_extra\" "$ac_file_inputs" | $AWK -f "$ac_tmp/subs.awk" \
+  >$ac_tmp/out || as_fn_error $? "could not create $ac_file" "$LINENO" 5
 
 test -z "$ac_datarootdir_hack$ac_datarootdir_seen" &&
-  { ac_out=`sed -n '/\${datarootdir}/p' "$tmp/out"`; test -n "$ac_out"; } &&
-  { ac_out=`sed -n '/^[	 ]*datarootdir[	 ]*:*=/p' "$tmp/out"`; test -z "$ac_out"; } &&
+  { ac_out=`sed -n '/\${datarootdir}/p' "$ac_tmp/out"`; test -n "$ac_out"; } &&
+  { ac_out=`sed -n '/^[	 ]*datarootdir[	 ]*:*=/p' \
+      "$ac_tmp/out"`; test -z "$ac_out"; } &&
   { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: $ac_file contains a reference to the variable \`datarootdir'
-which seems to be undefined.  Please make sure it is defined." >&5
+which seems to be undefined.  Please make sure it is defined" >&5
 $as_echo "$as_me: WARNING: $ac_file contains a reference to the variable \`datarootdir'
-which seems to be undefined.  Please make sure it is defined." >&2;}
+which seems to be undefined.  Please make sure it is defined" >&2;}
 
-  rm -f "$tmp/stdin"
+  rm -f "$ac_tmp/stdin"
   case $ac_file in
-  -) cat "$tmp/out" && rm -f "$tmp/out";;
-  *) rm -f "$ac_file" && mv "$tmp/out" "$ac_file";;
+  -) cat "$ac_tmp/out" && rm -f "$ac_tmp/out";;
+  *) rm -f "$ac_file" && mv "$ac_tmp/out" "$ac_file";;
   esac \
-  || as_fn_error "could not create $ac_file" "$LINENO" 5
+  || as_fn_error $? "could not create $ac_file" "$LINENO" 5
  ;;
   :H)
   #
@@ -4227,21 +4187,21 @@ which seems to be undefined.  Please mak
   if test x"$ac_file" != x-; then
     {
       $as_echo "/* $configure_input  */" \
-      && eval '$AWK -f "$tmp/defines.awk"' "$ac_file_inputs"
-    } >"$tmp/config.h" \
-      || as_fn_error "could not create $ac_file" "$LINENO" 5
-    if diff "$ac_file" "$tmp/config.h" >/dev/null 2>&1; then
+      && eval '$AWK -f "$ac_tmp/defines.awk"' "$ac_file_inputs"
+    } >"$ac_tmp/config.h" \
+      || as_fn_error $? "could not create $ac_file" "$LINENO" 5
+    if diff "$ac_file" "$ac_tmp/config.h" >/dev/null 2>&1; then
       { $as_echo "$as_me:${as_lineno-$LINENO}: $ac_file is unchanged" >&5
 $as_echo "$as_me: $ac_file is unchanged" >&6;}
     else
       rm -f "$ac_file"
-      mv "$tmp/config.h" "$ac_file" \
-	|| as_fn_error "could not create $ac_file" "$LINENO" 5
+      mv "$ac_tmp/config.h" "$ac_file" \
+	|| as_fn_error $? "could not create $ac_file" "$LINENO" 5
     fi
   else
     $as_echo "/* $configure_input  */" \
-      && eval '$AWK -f "$tmp/defines.awk"' "$ac_file_inputs" \
-      || as_fn_error "could not create -" "$LINENO" 5
+      && eval '$AWK -f "$ac_tmp/defines.awk"' "$ac_file_inputs" \
+      || as_fn_error $? "could not create -" "$LINENO" 5
   fi
  ;;
 
@@ -4258,7 +4218,7 @@ _ACEOF
 ac_clean_files=$ac_clean_files_save
 
 test $ac_write_fail = 0 ||
-  as_fn_error "write failure creating $CONFIG_STATUS" "$LINENO" 5
+  as_fn_error $? "write failure creating $CONFIG_STATUS" "$LINENO" 5
 
 
 # configure is writing to config.log, and then calls config.status.
@@ -4279,7 +4239,7 @@ if test "$no_create" != yes; then
   exec 5>>config.log
   # Use ||, not &&, to avoid exiting from the if with $? = 1, which
   # would make configure fail if this is the last instruction.
-  $ac_cs_success || as_fn_exit $?
+  $ac_cs_success || as_fn_exit 1
 fi
 if test -n "$ac_unrecognized_opts" && test "$enable_option_checking" != no; then
   { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: unrecognized options: $ac_unrecognized_opts" >&5

Modified: polly/trunk/include/polly/Config/config.h.cmake
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/include/polly/Config/config.h.cmake?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/include/polly/Config/config.h.cmake (original)
+++ polly/trunk/include/polly/Config/config.h.cmake Fri Apr 11 04:47:45 2014
@@ -14,7 +14,6 @@
 #define POLLY_CONFIG_H
 
 #cmakedefine CLOOG_FOUND
-#cmakedefine OPENSCOP_FOUND
 #cmakedefine PLUTO_FOUND
 #cmakedefine SCOPLIB_FOUND
 #cmakedefine CUDALIB_FOUND

Modified: polly/trunk/include/polly/Config/config.h.in
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/include/polly/Config/config.h.in?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/include/polly/Config/config.h.in (original)
+++ polly/trunk/include/polly/Config/config.h.in Fri Apr 11 04:47:45 2014
@@ -12,9 +12,6 @@
 /* Define if gpu codegen is enabled */
 #undef GPU_CODEGEN
 
-/* Define if openscop found */
-#undef OPENSCOP_FOUND
-
 /* Define to the address where bug reports for this package should be sent. */
 #undef PACKAGE_BUGREPORT
 

Modified: polly/trunk/include/polly/LinkAllPasses.h
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/include/polly/LinkAllPasses.h?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/include/polly/LinkAllPasses.h (original)
+++ polly/trunk/include/polly/LinkAllPasses.h Fri Apr 11 04:47:45 2014
@@ -53,11 +53,6 @@ llvm::Pass *createIslCodeGenerationPass(
 llvm::Pass *createIslScheduleOptimizerPass();
 llvm::Pass *createTempScopInfoPass();
 
-#ifdef OPENSCOP_FOUND
-llvm::Pass *createScopExporterPass();
-llvm::Pass *createScopImporterPass();
-#endif
-
 #ifdef SCOPLIB_FOUND
 llvm::Pass *createPoccPass();
 llvm::Pass *createScopLibExporterPass();
@@ -107,10 +102,6 @@ struct PollyForcePassLinking {
     createIslScheduleOptimizerPass();
     createTempScopInfoPass();
 
-#ifdef OPENSCOP_FOUND
-    createScopExporterPass();
-    createScopImporterPass();
-#endif
 #ifdef SCOPLIB_FOUND
     createPoccPass();
     createScopLibExporterPass();

Modified: polly/trunk/lib/CMakeLists.txt
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/CMakeLists.txt?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/lib/CMakeLists.txt (original)
+++ polly/trunk/lib/CMakeLists.txt Fri Apr 11 04:47:45 2014
@@ -25,12 +25,6 @@ if (GPU_CODEGEN)
        CodeGen/PTXGenerator.cpp)
 endif (GPU_CODEGEN)
 
-if (OPENSCOP_FOUND)
-  set(POLLY_OPENSCOP_FILES
-      Exchange/OpenScopImporter.cpp
-      Exchange/OpenScopExporter.cpp)
-endif (OPENSCOP_FOUND)
-
 if (SCOPLIB_FOUND)
   set(POLLY_SCOPLIB_FILES
       Transform/Pocc.cpp
@@ -60,7 +54,6 @@ add_polly_library(Polly
   Support/RegisterPasses.cpp
   Support/ScopHelper.cpp
   ${POLLY_JSON_FILES}
-  ${POLLY_OPENSCOP_FILES}
   Transform/Canonicalization.cpp
   Transform/CodePreparation.cpp
   Transform/DeadCodeElimination.cpp

Removed: polly/trunk/lib/Exchange/OpenScopExporter.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Exchange/OpenScopExporter.cpp?rev=206025&view=auto
==============================================================================
--- polly/trunk/lib/Exchange/OpenScopExporter.cpp (original)
+++ polly/trunk/lib/Exchange/OpenScopExporter.cpp (removed)
@@ -1,573 +0,0 @@
-//===-- OpenScopExporter.cpp  - Export Scops with openscop library --------===//
-//
-//                     The LLVM Compiler Infrastructure
-//
-// This file is distributed under the University of Illinois Open Source
-// License. See LICENSE.TXT for details.
-//
-//===----------------------------------------------------------------------===//
-//
-// Export the Scops build by ScopInfo pass to text file.
-//
-//===----------------------------------------------------------------------===//
-
-#include "polly/LinkAllPasses.h"
-
-#ifdef OPENSCOP_FOUND
-
-#include "polly/Options.h"
-#include "polly/ScopInfo.h"
-#include "polly/ScopPass.h"
-
-#define OPENSCOP_INT_T_IS_MP
-#include "openscop/openscop.h"
-
-#include "stdio.h"
-#include "isl/map.h"
-#include "isl/set.h"
-#include "isl/constraint.h"
-
-using namespace llvm;
-using namespace polly;
-
-namespace {
-static cl::opt<std::string>
-ExportDir("polly-export-dir",
-          cl::desc("The directory to export the .scop files to."), cl::Hidden,
-          cl::value_desc("Directory path"), cl::ValueRequired, cl::init("."),
-          cl::cat(PollyCategory));
-
-struct ScopExporter : public ScopPass {
-  static char ID;
-  Scop *S;
-  explicit ScopExporter() : ScopPass(ID) {}
-
-  std::string getFileName(Scop *S) const;
-
-  virtual bool runOnScop(Scop &S);
-  void printScop(raw_ostream &OS) const;
-  void getAnalysisUsage(AnalysisUsage &AU) const;
-};
-}
-
-char ScopExporter::ID = 0;
-
-class OpenScop {
-  Scop *PollyScop;
-  openscop_scop_p openscop;
-
-  std::map<const Value *, int> ArrayMap;
-
-  void initializeArrays();
-  void initializeParameters();
-  void initializeScattering();
-  void initializeStatements();
-  openscop_statement_p initializeStatement(ScopStmt *stmt);
-  void freeStatement(openscop_statement_p stmt);
-  static int accessToMatrix_constraint(isl_constraint *c, void *user);
-  static int accessToMatrix_basic_map(isl_basic_map *bmap, void *user);
-  openscop_matrix_p createAccessMatrix(ScopStmt *S, bool isRead);
-  static int domainToMatrix_constraint(isl_constraint *c, void *user);
-  static int domainToMatrix_basic_set(isl_basic_set *bset, void *user);
-  openscop_matrix_p domainToMatrix(isl_set *PS);
-  static int scatteringToMatrix_constraint(isl_constraint *c, void *user);
-  static int scatteringToMatrix_basic_map(isl_basic_map *bmap, void *user);
-  openscop_matrix_p scatteringToMatrix(isl_map *pmap);
-
-public:
-  OpenScop(Scop *S);
-  ~OpenScop();
-  void print(FILE *F);
-};
-
-OpenScop::OpenScop(Scop *S) : PollyScop(S) {
-  openscop = openscop_scop_malloc();
-
-  initializeArrays();
-  initializeParameters();
-  initializeScattering();
-  initializeStatements();
-}
-
-void OpenScop::initializeParameters() {
-  openscop->nb_parameters = PollyScop->getNumParams();
-  openscop->parameters = new char *[openscop->nb_parameters];
-
-  for (int i = 0; i < openscop->nb_parameters; ++i) {
-    openscop->parameters[i] = new char[20];
-    sprintf(openscop->parameters[i], "p_%d", i);
-  }
-}
-
-void OpenScop::initializeArrays() {
-  int nb_arrays = 0;
-
-  for (Scop::iterator SI = PollyScop->begin(), SE = PollyScop->end(); SI != SE;
-       ++SI)
-    for (ScopStmt::memacc_iterator MI = (*SI)->memacc_begin(),
-                                   ME = (*SI)->memacc_end();
-         MI != ME; ++MI) {
-      const Value *BaseAddr = (*MI)->getBaseAddr();
-      if (ArrayMap.find(BaseAddr) == ArrayMap.end()) {
-        ArrayMap.insert(std::make_pair(BaseAddr, nb_arrays));
-        ++nb_arrays;
-      }
-    }
-
-  openscop->nb_arrays = nb_arrays;
-  openscop->arrays = new char *[nb_arrays];
-
-  for (int i = 0; i < nb_arrays; ++i)
-    for (std::map<const Value *, int>::iterator VI = ArrayMap.begin(),
-                                                VE = ArrayMap.end();
-         VI != VE; ++VI)
-      if ((*VI).second == i) {
-        const Value *V = (*VI).first;
-        std::string name = V->getName();
-        openscop->arrays[i] = new char[name.size() + 1];
-        strcpy(openscop->arrays[i], name.c_str());
-      }
-}
-
-void OpenScop::initializeScattering() {
-  openscop->nb_scattdims = PollyScop->getScatterDim();
-  openscop->scattdims = new char *[openscop->nb_scattdims];
-
-  for (int i = 0; i < openscop->nb_scattdims; ++i) {
-    openscop->scattdims[i] = new char[20];
-    sprintf(openscop->scattdims[i], "s_%d", i);
-  }
-}
-
-openscop_statement_p OpenScop::initializeStatement(ScopStmt *stmt) {
-  openscop_statement_p Stmt = openscop_statement_malloc();
-
-  // Domain & Schedule
-  isl_set *domain = stmt->getDomain();
-  Stmt->domain = domainToMatrix(domain);
-  isl_map *Scattering = stmt->getScattering();
-  Stmt->schedule = scatteringToMatrix(Scattering);
-  isl_set_free(domain);
-  isl_map_free(Scattering);
-
-  // Statement name
-  const char *entryName = stmt->getBaseName();
-  Stmt->body = (char *)malloc(sizeof(char) * (strlen(entryName) + 1));
-  strcpy(Stmt->body, entryName);
-
-  // Iterator names
-  Stmt->nb_iterators = isl_set_n_dim(stmt->getDomain());
-  Stmt->iterators = new char *[Stmt->nb_iterators];
-
-  for (int i = 0; i < Stmt->nb_iterators; ++i) {
-    Stmt->iterators[i] = new char[20];
-    sprintf(Stmt->iterators[i], "i_%d", i);
-  }
-
-  // Memory Accesses
-  Stmt->read = createAccessMatrix(stmt, true);
-  Stmt->write = createAccessMatrix(stmt, false);
-
-  return Stmt;
-}
-
-void OpenScop::initializeStatements() {
-  for (Scop::reverse_iterator SI = PollyScop->rbegin(), SE = PollyScop->rend();
-       SI != SE; ++SI) {
-    openscop_statement_p stmt = initializeStatement(*SI);
-    stmt->next = openscop->statement;
-    openscop->statement = stmt;
-  }
-}
-
-void OpenScop::freeStatement(openscop_statement_p stmt) {
-  if (stmt->read)
-    openscop_matrix_free(stmt->read);
-  stmt->read = NULL;
-
-  if (stmt->write)
-    openscop_matrix_free(stmt->write);
-  stmt->write = NULL;
-
-  if (stmt->domain)
-    openscop_matrix_free(stmt->domain);
-  stmt->domain = NULL;
-
-  if (stmt->schedule)
-    openscop_matrix_free(stmt->schedule);
-  stmt->schedule = NULL;
-
-  for (int i = 0; i < stmt->nb_iterators; ++i)
-    delete[](stmt->iterators[i]);
-
-  delete[](stmt->iterators);
-  stmt->iterators = NULL;
-  stmt->nb_iterators = 0;
-
-  delete[](stmt->body);
-  stmt->body = NULL;
-
-  openscop_statement_free(stmt);
-}
-
-void OpenScop::print(FILE *F) { openscop_scop_print_dot_scop(F, openscop); }
-
-/// Add an isl constraint to an OpenScop matrix.
-///
-/// @param user The matrix
-/// @param c The constraint
-int OpenScop::domainToMatrix_constraint(isl_constraint *c, void *user) {
-  openscop_matrix_p m = (openscop_matrix_p)user;
-
-  int nb_params = isl_constraint_dim(c, isl_space_param);
-  int nb_vars = isl_constraint_dim(c, isl_space_set);
-  int nb_div = isl_constraint_dim(c, isl_space_div);
-
-  assert(!nb_div && "Existentially quantified variables not yet supported");
-
-  openscop_vector_p vec = openscop_vector_malloc(nb_params + nb_vars + 2);
-
-  // Assign type
-  if (isl_constraint_is_equality(c))
-    openscop_vector_tag_equality(vec);
-  else
-    openscop_vector_tag_inequality(vec);
-
-  isl_int v;
-  isl_int_init(v);
-
-  // Assign variables
-  for (int i = 0; i < nb_vars; ++i) {
-    isl_constraint_get_coefficient(c, isl_space_set, i, &v);
-    isl_int_set(vec->p[i + 1], v);
-  }
-
-  // Assign parameters
-  for (int i = 0; i < nb_params; ++i) {
-    isl_constraint_get_coefficient(c, isl_space_param, i, &v);
-    isl_int_set(vec->p[nb_vars + i + 1], v);
-  }
-
-  // Assign constant
-  isl_constraint_get_constant(c, &v);
-  isl_int_set(vec->p[nb_params + nb_vars + 1], v);
-
-  openscop_matrix_insert_vector(m, vec, m->NbRows);
-
-  return 0;
-}
-
-/// Add an isl basic set to a OpenScop matrix_list
-///
-/// @param bset The basic set to add
-/// @param user The matrix list we should add the basic set to
-///
-/// XXX: At the moment this function expects just a matrix, as support
-/// for matrix lists is currently not available in OpenScop. So union of
-/// polyhedron are not yet supported
-int OpenScop::domainToMatrix_basic_set(isl_basic_set *bset, void *user) {
-  openscop_matrix_p m = (openscop_matrix_p)user;
-  assert(!m->NbRows && "Union of polyhedron not yet supported");
-
-  isl_basic_set_foreach_constraint(bset, &domainToMatrix_constraint, user);
-  return 0;
-}
-
-/// Translate a isl_set to a OpenScop matrix.
-///
-/// @param PS The set to be translated
-/// @return A OpenScop Matrix
-openscop_matrix_p OpenScop::domainToMatrix(isl_set *PS) {
-  // Create a canonical copy of this set.
-  isl_set *set = isl_set_copy(PS);
-  set = isl_set_compute_divs(set);
-  set = isl_set_align_divs(set);
-
-  // Initialize the matrix.
-  unsigned NbRows, NbColumns;
-  NbRows = 0;
-  NbColumns = isl_set_n_dim(PS) + isl_set_n_param(PS) + 2;
-  openscop_matrix_p matrix = openscop_matrix_malloc(NbRows, NbColumns);
-
-  // Copy the content into the matrix.
-  isl_set_foreach_basic_set(set, &domainToMatrix_basic_set, matrix);
-
-  isl_set_free(set);
-
-  return matrix;
-}
-
-/// Add an isl constraint to an OpenScop matrix.
-///
-/// @param user The matrix
-/// @param c The constraint
-int OpenScop::scatteringToMatrix_constraint(isl_constraint *c, void *user) {
-  openscop_matrix_p m = (openscop_matrix_p)user;
-
-  int nb_params = isl_constraint_dim(c, isl_space_param);
-  int nb_in = isl_constraint_dim(c, isl_space_in);
-  int nb_out = isl_constraint_dim(c, isl_space_out);
-  int nb_div = isl_constraint_dim(c, isl_space_div);
-
-  assert(!nb_div && "Existentially quantified variables not yet supported");
-
-  openscop_vector_p vec =
-      openscop_vector_malloc(nb_params + nb_in + nb_out + 2);
-
-  // Assign type
-  if (isl_constraint_is_equality(c))
-    openscop_vector_tag_equality(vec);
-  else
-    openscop_vector_tag_inequality(vec);
-
-  isl_int v;
-  isl_int_init(v);
-
-  // Assign scattering
-  for (int i = 0; i < nb_out; ++i) {
-    isl_constraint_get_coefficient(c, isl_space_out, i, &v);
-    isl_int_set(vec->p[i + 1], v);
-  }
-
-  // Assign variables
-  for (int i = 0; i < nb_in; ++i) {
-    isl_constraint_get_coefficient(c, isl_space_in, i, &v);
-    isl_int_set(vec->p[nb_out + i + 1], v);
-  }
-
-  // Assign parameters
-  for (int i = 0; i < nb_params; ++i) {
-    isl_constraint_get_coefficient(c, isl_space_param, i, &v);
-    isl_int_set(vec->p[nb_out + nb_in + i + 1], v);
-  }
-
-  // Assign constant
-  isl_constraint_get_constant(c, &v);
-  isl_int_set(vec->p[nb_out + nb_in + nb_params + 1], v);
-
-  openscop_matrix_insert_vector(m, vec, m->NbRows);
-
-  return 0;
-}
-
-/// Add an isl basic map to a OpenScop matrix_list
-///
-/// @param bmap The basic map to add
-/// @param user The matrix list we should add the basic map to
-///
-/// XXX: At the moment this function expects just a matrix, as support
-/// for matrix lists is currently not available in OpenScop. So union of
-/// polyhedron are not yet supported
-int OpenScop::scatteringToMatrix_basic_map(isl_basic_map *bmap, void *user) {
-  openscop_matrix_p m = (openscop_matrix_p)user;
-  assert(!m->NbRows && "Union of polyhedron not yet supported");
-
-  isl_basic_map_foreach_constraint(bmap, &scatteringToMatrix_constraint, user);
-  return 0;
-}
-
-/// Translate a isl_map to a OpenScop matrix.
-///
-/// @param map The map to be translated
-/// @return A OpenScop Matrix
-openscop_matrix_p OpenScop::scatteringToMatrix(isl_map *pmap) {
-  // Create a canonical copy of this set.
-  isl_map *map = isl_map_copy(pmap);
-  map = isl_map_compute_divs(map);
-  map = isl_map_align_divs(map);
-
-  // Initialize the matrix.
-  unsigned NbRows, NbColumns;
-  NbRows = 0;
-  NbColumns =
-      isl_map_n_in(pmap) + isl_map_n_out(pmap) + isl_map_n_param(pmap) + 2;
-  openscop_matrix_p matrix = openscop_matrix_malloc(NbRows, NbColumns);
-
-  // Copy the content into the matrix.
-  isl_map_foreach_basic_map(map, &scatteringToMatrix_basic_map, matrix);
-
-  isl_map_free(map);
-
-  return matrix;
-}
-
-/// Add an isl constraint to an OpenScop matrix.
-///
-/// @param user The matrix
-/// @param c The constraint
-int OpenScop::accessToMatrix_constraint(isl_constraint *c, void *user) {
-  openscop_matrix_p m = (openscop_matrix_p)user;
-
-  int nb_params = isl_constraint_dim(c, isl_space_param);
-  int nb_in = isl_constraint_dim(c, isl_space_in);
-  int nb_div = isl_constraint_dim(c, isl_space_div);
-
-  assert(!nb_div && "Existentially quantified variables not yet supported");
-
-  openscop_vector_p vec = openscop_vector_malloc(nb_params + nb_in + 2);
-
-  isl_int v;
-  isl_int_init(v);
-
-  // The access dimension has to be one.
-  isl_constraint_get_coefficient(c, isl_space_out, 0, &v);
-  assert(isl_int_is_one(v));
-  bool inverse = true;
-
-  // Assign variables
-  for (int i = 0; i < nb_in; ++i) {
-    isl_constraint_get_coefficient(c, isl_space_in, i, &v);
-
-    if (inverse)
-      isl_int_neg(v, v);
-
-    isl_int_set(vec->p[i + 1], v);
-  }
-
-  // Assign parameters
-  for (int i = 0; i < nb_params; ++i) {
-    isl_constraint_get_coefficient(c, isl_space_param, i, &v);
-
-    if (inverse)
-      isl_int_neg(v, v);
-
-    isl_int_set(vec->p[nb_in + i + 1], v);
-  }
-
-  // Assign constant
-  isl_constraint_get_constant(c, &v);
-
-  if (inverse)
-    isl_int_neg(v, v);
-
-  isl_int_set(vec->p[nb_in + nb_params + 1], v);
-
-  openscop_matrix_insert_vector(m, vec, m->NbRows);
-
-  return 0;
-}
-
-/// Add an isl basic map to a OpenScop matrix_list
-///
-/// @param bmap The basic map to add
-/// @param user The matrix list we should add the basic map to
-///
-/// XXX: At the moment this function expects just a matrix, as support
-/// for matrix lists is currently not available in OpenScop. So union of
-/// polyhedron are not yet supported
-int OpenScop::accessToMatrix_basic_map(isl_basic_map *bmap, void *user) {
-  isl_basic_map_foreach_constraint(bmap, &accessToMatrix_constraint, user);
-  return 0;
-}
-
-/// Create the memory access matrix for openscop
-///
-/// @param S The polly statement the access matrix is created for.
-/// @param isRead Are we looking for read or write accesses?
-/// @param ArrayMap A map translating from the memory references to the openscop
-/// indeces
-///
-/// @return The memory access matrix, as it is required by openscop.
-openscop_matrix_p OpenScop::createAccessMatrix(ScopStmt *S, bool isRead) {
-  unsigned NbColumns = S->getNumIterators() + S->getNumParams() + 2;
-  openscop_matrix_p m = openscop_matrix_malloc(0, NbColumns);
-
-  for (ScopStmt::memacc_iterator MI = S->memacc_begin(), ME = S->memacc_end();
-       MI != ME; ++MI)
-    if ((*MI)->isRead() == isRead) {
-      // Extract the access function.
-      isl_map_foreach_basic_map((*MI)->getAccessFunction(),
-                                &accessToMatrix_basic_map, m);
-
-      // Set the index of the memory access base element.
-      std::map<const Value *, int>::iterator BA =
-          ArrayMap.find((*MI)->getBaseAddr());
-      isl_int_set_si(m->p[m->NbRows - 1][0], (*BA).second + 1);
-    }
-
-  return m;
-}
-
-OpenScop::~OpenScop() {
-  // Free array names.
-  for (int i = 0; i < openscop->nb_arrays; ++i)
-    delete[](openscop->arrays[i]);
-
-  delete[](openscop->arrays);
-  openscop->arrays = NULL;
-  openscop->nb_arrays = 0;
-
-  // Free scattering names.
-  for (int i = 0; i < openscop->nb_scattdims; ++i)
-    delete[](openscop->scattdims[i]);
-
-  delete[](openscop->scattdims);
-  openscop->scattdims = NULL;
-  openscop->nb_scattdims = 0;
-
-  // Free parameters
-  for (int i = 0; i < openscop->nb_parameters; ++i)
-    delete[](openscop->parameters[i]);
-
-  delete[](openscop->parameters);
-  openscop->parameters = NULL;
-  openscop->nb_parameters = 0;
-
-  openscop_statement_p stmt = openscop->statement;
-
-  // Free Statements
-  while (stmt) {
-    openscop_statement_p TempStmt = stmt->next;
-    stmt->next = NULL;
-    freeStatement(stmt);
-    stmt = TempStmt;
-  }
-
-  openscop->statement = NULL;
-
-  openscop_scop_free(openscop);
-}
-
-std::string ScopExporter::getFileName(Scop *S) const {
-  std::string FunctionName = S->getRegion().getEntry()->getParent()->getName();
-  std::string FileName = FunctionName + "___" + S->getNameStr() + ".scop";
-  return FileName;
-}
-
-void ScopExporter::printScop(raw_ostream &OS) const { S->print(OS); }
-
-bool ScopExporter::runOnScop(Scop &scop) {
-  S = &scop;
-  Region &R = S->getRegion();
-
-  std::string FileName = ExportDir + "/" + getFileName(S);
-  FILE *F = fopen(FileName.c_str(), "w");
-
-  if (!F) {
-    errs() << "Cannot open file: " << FileName << "\n";
-    errs() << "Skipping export.\n";
-    return false;
-  }
-
-  OpenScop openscop(S);
-  openscop.print(F);
-  fclose(F);
-
-  std::string FunctionName = R.getEntry()->getParent()->getName();
-  errs() << "Writing Scop '" << R.getNameStr() << "' in function '"
-         << FunctionName << "' to '" << FileName << "'.\n";
-
-  return false;
-}
-
-void ScopExporter::getAnalysisUsage(AnalysisUsage &AU) const {
-  ScopPass::getAnalysisUsage(AU);
-}
-
-static RegisterPass<ScopExporter> A("polly-export",
-                                    "Polly - Export Scops with OpenScop library"
-                                    " (Writes a .scop file for each Scop)");
-
-Pass *polly::createScopExporterPass() { return new ScopExporter(); }
-
-#endif

Removed: polly/trunk/lib/Exchange/OpenScopImporter.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Exchange/OpenScopImporter.cpp?rev=206025&view=auto
==============================================================================
--- polly/trunk/lib/Exchange/OpenScopImporter.cpp (original)
+++ polly/trunk/lib/Exchange/OpenScopImporter.cpp (removed)
@@ -1,243 +0,0 @@
-//===-- OpenScopImporter.cpp  - Import Scops with openscop library --------===//
-//
-//                     The LLVM Compiler Infrastructure
-//
-// This file is distributed under the University of Illinois Open Source
-// License. See LICENSE.TXT for details.
-//
-//===----------------------------------------------------------------------===//
-//
-// Import modified .scop files into Polly. This allows to change the schedule of
-// statements.
-//
-//===----------------------------------------------------------------------===//
-
-#include "polly/LinkAllPasses.h"
-#include "polly/Dependences.h"
-#include "polly/Options.h"
-#include "polly/ScopInfo.h"
-#include "polly/ScopPass.h"
-
-#ifdef OPENSCOP_FOUND
-
-#define OPENSCOP_INT_T_IS_MP
-#include "openscop/openscop.h"
-
-#include "isl/map.h"
-#include "isl/set.h"
-#include "isl/constraint.h"
-
-using namespace llvm;
-using namespace polly;
-
-namespace {
-static cl::opt<std::string>
-ImportDir("polly-import-dir",
-          cl::desc("The directory to import the .scop files from."), cl::Hidden,
-          cl::value_desc("Directory path"), cl::ValueRequired, cl::init("."));
-static cl::opt<std::string>
-ImportPostfix("polly-import-postfix",
-              cl::desc("Postfix to append to the import .scop files."),
-              cl::Hidden, cl::value_desc("File postfix"), cl::ValueRequired,
-              cl::init(""));
-
-struct ScopImporter : public ScopPass {
-  static char ID;
-  Scop *S;
-  Dependences *D;
-  explicit ScopImporter() : ScopPass(ID) {}
-  bool updateScattering(Scop *S, openscop_scop_p OScop);
-
-  std::string getFileName(Scop *S) const;
-  virtual bool runOnScop(Scop &S);
-  virtual void printScop(raw_ostream &OS) const;
-  void getAnalysisUsage(AnalysisUsage &AU) const;
-};
-}
-
-char ScopImporter::ID = 0;
-
-/// @brief Create an isl constraint from a row of OpenScop integers.
-///
-/// @param row An array of isl/OpenScop integers.
-/// @param Space An isl space object, describing how to spilt the dimensions.
-///
-/// @return An isl constraint representing this integer array.
-isl_constraint *constraintFromMatrixRow(isl_int *row, isl_space *Space) {
-  isl_constraint *c;
-
-  unsigned NbOut = isl_space_size(Space, isl_dim_out);
-  unsigned NbIn = isl_space_size(Space, isl_dim_in);
-  unsigned NbParam = isl_space_size(Space, isl_dim_param);
-
-  if (isl_int_is_zero(row[0]))
-    c = isl_equality_alloc(isl_space_copy(Space));
-  else
-    c = isl_inequality_alloc(isl_space_copy(Space));
-
-  unsigned current_column = 1;
-
-  for (unsigned j = 0; j < NbOut; ++j)
-    isl_constraint_set_coefficient(c, isl_space_out, j, row[current_column++]);
-
-  for (unsigned j = 0; j < NbIn; ++j)
-    isl_constraint_set_coefficient(c, isl_space_in, j, row[current_column++]);
-
-  for (unsigned j = 0; j < NbParam; ++j)
-    isl_constraint_set_coefficient(c, isl_space_param, j,
-                                   row[current_column++]);
-
-  isl_constraint_set_constant(c, row[current_column]);
-
-  return c;
-}
-
-/// @brief Create an isl map from a OpenScop matrix.
-///
-/// @param m The OpenScop matrix to translate.
-/// @param Space The dimensions that are contained in the OpenScop matrix.
-///
-/// @return An isl map representing m.
-isl_map *mapFromMatrix(openscop_matrix_p m, isl_space *Space) {
-  isl_basic_map *bmap = isl_basic_map_universe(isl_space_copy(Space));
-
-  for (unsigned i = 0; i < m->NbRows; ++i) {
-    isl_constraint *c;
-
-    c = constraintFromMatrixRow(m->p[i], Space);
-    bmap = isl_basic_map_add_constraint(bmap, c);
-  }
-
-  return isl_map_from_basic_map(bmap);
-}
-
-/// @brief Create a new scattering for PollyStmt.
-///
-/// @param m The matrix describing the new scattering.
-/// @param PollyStmt The statement to create the scattering for.
-///
-/// @return An isl_map describing the scattering.
-isl_map *scatteringForStmt(openscop_matrix_p m, ScopStmt *PollyStmt) {
-  unsigned NbParam = PollyStmt->getNumParams();
-  unsigned NbIterators = PollyStmt->getNumIterators();
-  unsigned NbScattering = m->NbColumns - 2 - NbParam - NbIterators;
-
-  isl_ctx *ctx = PollyStmt->getParent()->getCtx();
-  isl_space *Space = isl_dim_alloc(ctx, NbParam, NbIterators, NbScattering);
-  Space = isl_space_set_tuple_name(Space, isl_dim_out, "scattering");
-  Space = isl_space_set_tuple_name(Space, isl_dim_in, PollyStmt->getBaseName());
-  isl_map *map = mapFromMatrix(m, Space);
-  isl_space_free(Space);
-
-  return map;
-}
-
-typedef Dependences::StatementToIslMapTy StatementToIslMapTy;
-
-/// @brief Read the new scattering from the OpenScop description.
-///
-/// @S      The Scop to update
-/// @OScop  The OpenScop data structure describing the new scattering.
-/// @return A map that contains for each Statement the new scattering.
-StatementToIslMapTy *readScattering(Scop *S, openscop_scop_p OScop) {
-  StatementToIslMapTy &NewScattering = *(new StatementToIslMapTy());
-  openscop_statement_p stmt = OScop->statement;
-
-  for (Scop::iterator SI = S->begin(), SE = S->end(); SI != SE; ++SI) {
-    if (!stmt) {
-      errs() << "Not enough statements available in OpenScop file\n";
-      delete &NewScattering;
-      return NULL;
-    }
-
-    NewScattering[*SI] = scatteringForStmt(stmt->schedule, *SI);
-    stmt = stmt->next;
-  }
-
-  if (stmt) {
-    errs() << "Too many statements in OpenScop file\n";
-    delete &NewScattering;
-    return NULL;
-  }
-
-  return &NewScattering;
-}
-
-/// @brief Update the scattering in a Scop using the OpenScop description of
-/// the scattering.
-///
-/// @S The Scop to update
-/// @OScop The OpenScop data structure describing the new scattering.
-/// @return Returns false, if the update failed.
-bool ScopImporter::updateScattering(Scop *S, openscop_scop_p OScop) {
-  StatementToIslMapTy *NewScattering = readScattering(S, OScop);
-
-  if (!NewScattering)
-    return false;
-
-  if (!D->isValidScattering(NewScattering)) {
-    errs() << "OpenScop file contains a scattering that changes the "
-           << "dependences. Use -disable-polly-legality to continue anyways\n";
-    return false;
-  }
-
-  for (Scop::iterator SI = S->begin(), SE = S->end(); SI != SE; ++SI) {
-    ScopStmt *Stmt = *SI;
-
-    if (NewScattering->find(Stmt) != NewScattering->end())
-      Stmt->setScattering((*NewScattering)[Stmt]);
-  }
-
-  return true;
-}
-std::string ScopImporter::getFileName(Scop *S) const {
-  std::string FunctionName = S->getRegion().getEntry()->getParent()->getName();
-  std::string FileName = FunctionName + "___" + S->getNameStr() + ".scop";
-  return FileName;
-}
-
-void ScopImporter::printScop(raw_ostream &OS) const { S->print(OS); }
-
-bool ScopImporter::runOnScop(Scop &scop) {
-  S = &scop;
-  Region &R = scop.getRegion();
-  D = &getAnalysis<Dependences>();
-
-  std::string FileName = ImportDir + "/" + getFileName(S) + ImportPostfix;
-  FILE *F = fopen(FileName.c_str(), "r");
-
-  if (!F) {
-    errs() << "Cannot open file: " << FileName << "\n";
-    errs() << "Skipping import.\n";
-    return false;
-  }
-
-  openscop_scop_p openscop = openscop_scop_read(F);
-  fclose(F);
-
-  std::string FunctionName = R.getEntry()->getParent()->getName();
-  errs() << "Reading Scop '" << R.getNameStr() << "' in function '"
-         << FunctionName << "' from '" << FileName << "'.\n";
-
-  bool UpdateSuccessfull = updateScattering(S, openscop);
-
-  if (!UpdateSuccessfull) {
-    errs() << "Update failed"
-           << "\n";
-  }
-
-  return false;
-}
-
-void ScopImporter::getAnalysisUsage(AnalysisUsage &AU) const {
-  ScopPass::getAnalysisUsage(AU);
-  AU.addRequired<Dependences>();
-}
-
-static RegisterPass<ScopImporter> A("polly-import",
-                                    "Polly - Import Scops with OpenScop library"
-                                    " (Reads a .scop file for each Scop)");
-
-Pass *polly::createScopImporterPass() { return new ScopImporter(); }
-
-#endif

Modified: polly/trunk/lib/Exchange/ScopLib.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Exchange/ScopLib.cpp?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/lib/Makefile (original)
+++ polly/trunk/lib/Makefile Fri Apr 11 04:47:45 2014
@@ -31,11 +31,6 @@ ifeq ($(PLUTO_FOUND), yes)
 POLLY_PLUTO_FILES= Transform/Pluto.cpp
 endif
 
-ifeq ($(OPENSCOP_FOUND), yes)
-POLLY_OPENSCOP_FILES= Exchange/OpenScopImporter.cpp \
-                      Exchange/OpenScopExporter.cpp
-endif
-
 ifeq ($(SCOPLIB_FOUND), yes)
 POLLY_SCOPLIB_FILES= Exchange/ScopLib.cpp \
                      Exchange/ScopLibExporter.cpp \
@@ -76,7 +71,6 @@ SOURCES= Polly.cpp \
 	 ${ISL_CODEGEN_FILES} \
          ${CLOOG_FILES} \
 	 ${POLLY_JSON_FILES} \
-	 ${POLLY_OPENSCOP_FILES} \
 	 ${POLLY_PLUTO_FILES} \
 	 ${POLLY_SCOPLIB_FILES}
 

Modified: polly/trunk/www/documentation/passes.html
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/documentation/passes.html?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/www/documentation/passes.html (original)
+++ polly/trunk/www/documentation/passes.html Fri Apr 11 04:47:45 2014
@@ -35,10 +35,6 @@
 <ul>
 <li><em>polly-export-cloog</em> Export the CLooG input file
 (Writes a .cloog file for each SCoP)</li>
-<li><em>polly-export</em> Export SCoPs with OpenScop library
-(Writes a .scop file for each SCoP)</li>
-<li><em>polly-import</em> Import SCoPs with OpenScop library
-(Reads a .scop file for each SCoP)</li>
 <li><em>polly-export-scoplib</em> Export SCoPs with ScopLib library
 (Writes a .scoplib file for each SCoP)</li>
 <li><em>polly-import-scoplib</em> Import SCoPs with ScopLib library

Modified: polly/trunk/www/example_manual_matmul.html
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/example_manual_matmul.html?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/www/example_manual_matmul.html (original)
+++ polly/trunk/www/example_manual_matmul.html Fri Apr 11 04:47:45 2014
@@ -359,8 +359,8 @@ for (c2=0;c2<=1535;c2+=64) {
 <li><h4>Codegenerate the SCoPs</h4>
 <p>
 This generates new code for the SCoPs detected by polly.
-If -polly-import is present, transformations specified in the imported openscop
-files will be applied.</p>
+If -polly-import-jscop is present, transformations specified in the imported
+jscop files will be applied.</p>
 <pre class="code">opt matmul.preopt.ll | opt -O3 > matmul.normalopt.ll</pre>
 <pre class="code">
 opt -basicaa \

Modified: polly/trunk/www/index.html
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/index.html?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/www/index.html (original)
+++ polly/trunk/www/index.html Fri Apr 11 04:47:45 2014
@@ -314,11 +314,6 @@ research tool.<br \>
   </tr>
 
   <tr>
-  <td><p>June </p></td>
-  <td><p>OpenSCoP import/export works (as far as openscop is finished).</p></td>
-  </tr>
-
-  <tr>
   <td><p>May</p></td>
   <td><p>The CLooG AST can be parsed.</p>
   </td>

Modified: polly/trunk/www/todo.html
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/www/todo.html?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================
--- polly/trunk/www/todo.html (original)
+++ polly/trunk/www/todo.html Fri Apr 11 04:47:45 2014
@@ -97,8 +97,7 @@ dead code elimination</a>
 </td><td>
 </td></tr>
 <th align="left"> <a
-href="http://llvm.org/bugs/show_bug.cgi?id=10229">OpenSCoP Import/Export - Update to
-current version</a>
+href="http://llvm.org/bugs/show_bug.cgi?id=10229">OpenSCoP Import/Export</a>
 </th><td class="nice">Open
 </td><td>
 </td></tr>
@@ -418,11 +417,6 @@ Ether
 </td><td>Tobias
 
 </td></tr>
-<tr>
-<th align="left"> Import/Export using current openscop version
-</td><td class="done"> Done
-</td><td>Tobias
-</td></tr>
 <tr><td colspan='4'> </td></tr>
 <tr><th colspan="3" style="background: rgb(239, 239, 239);"> Back End</th></tr>
 <tr style="background: rgb(239, 239, 239)">





More information about the llvm-commits mailing list
--- polly/trunk/lib/Exchange/ScopLib.cpp (original)
+++ polly/trunk/lib/Exchange/ScopLib.cpp Fri Apr 11 04:47:45 2014
@@ -498,9 +498,9 @@ ScopLib::~ScopLib() {
 
   scoplib_scop_free(scoplib);
 }
 /// @brief Create an isl constraint from a row of OpenScop integers.
 ///
 /// @param row An array of isl/OpenScop integers.
 /// @param Space An isl space object, describing how to spilt the dimensions.
 ///
 /// @return An isl constraint representing this integer array.
@@ -538,10 +538,10 @@ isl_constraint *constraintFromMatrixRow(
   return c;
 }
 
 /// @brief Create an isl map from a OpenScop matrix.
 ///
 /// @param m The OpenScop matrix to translate.
 /// @param Space The dimensions that are contained in the OpenScop matrix.
 ///
 /// @return An isl map representing m.
 isl_map *mapFromMatrix(scoplib_matrix_p m, __isl_take isl_space *Space,
@@ -566,9 +566,9 @@ isl_map *mapFromMatrix(scoplib_matrix_p
 
   return isl_map_from_basic_map(bmap);
 }
 /// @brief Create an isl constraint from a row of OpenScop integers.
 ///
 /// @param row An array of isl/OpenScop integers.
 /// @param Space An isl space object, describing how to spilt the dimensions.
 ///
 /// @return An isl constraint representing this integer array.
@@ -613,10 +613,10 @@ isl_constraint *constraintFromMatrixRowF
   return c;
 }
 
 /// @brief Create an isl map from a OpenScop matrix.
 ///
 /// @param m The OpenScop matrix to translate.
 /// @param Space The dimensions that are contained in the OpenScop matrix.
 ///
 /// @return An isl map representing m.
 isl_map *mapFromMatrix(scoplib_matrix_p m, __isl_take isl_space *Space) {
@@ -718,7 +718,7 @@ StatementToIslMapTy *readScattering(Scop
 
   for (Scop::iterator SI = S->begin(), SE = S->end(); SI != SE; ++SI) {
     if (!stmt) {
-      errs() << "Not enough statements available in OpenScop file\n";
+      errs() << "Not enough statements available in ScopLib file\n";
       freeStmtToIslMap(&NewScattering);
       return NULL;
     }
@@ -729,7 +729,7 @@ StatementToIslMapTy *readScattering(Scop
   }
 
   if (stmt) {
-    errs() << "Too many statements in OpenScop file\n";
+    errs() << "Too many statements in ScopLib file\n";
     freeStmtToIslMap(&NewScattering);
     return NULL;
   }
@@ -750,7 +750,7 @@ bool ScopLib::updateScattering() {
 
   if (!D->isValidScattering(NewScattering)) {
     freeStmtToIslMap(NewScattering);
-    errs() << "OpenScop file contains a scattering that changes the "
+    errs() << "ScopLib file contains a scattering that changes the "
            << "dependences. Use -disable-polly-legality to continue anyways\n";
     return false;
   }
@@ -498,9 +498,9 @@ ScopLib::~ScopLib() {
   scoplib_scop_free(scoplib);
 }
-/// @brief Create an isl constraint from a row of OpenScop integers.
+/// @brief Create an isl constraint from a row of ScopLib integers.
 ///
@@ -498,9 +498,9 @@ ScopLib::~ScopLib() {
 ///
-/// @param row An array of isl/OpenScop integers.
+/// @param row An array of isl/ScopLib integers.
 /// @param Space An isl space object, describing how to spilt the dimensions.
 ///
@@ -538,10 +538,10 @@ isl_constraint *constraintFromMatrixRow(
 }
 
-/// @brief Create an isl map from a OpenScop matrix.
+/// @brief Create an isl map from a ScopLib matrix.
 ///
@@ -538,10 +538,10 @@ isl_constraint *constraintFromMatrixRow(
 ///
-/// @param m The OpenScop matrix to translate.
-/// @param Space The dimensions that are contained in the OpenScop matrix.
+/// @param m The ScopLib matrix to translate.
+/// @param Space The dimensions that are contained in the ScopLib matrix.
 ///
 /// @return An isl map representing m.
@@ -566,9 +566,9 @@ isl_map *mapFromMatrix(scoplib_matrix_p
   return isl_map_from_basic_map(bmap);
 }
-/// @brief Create an isl constraint from a row of OpenScop integers.
+/// @brief Create an isl constraint from a row of ScopLib integers.
 ///
@@ -566,9 +566,9 @@ isl_map *mapFromMatrix(scoplib_matrix_p
 ///
-/// @param row An array of isl/OpenScop integers.
+/// @param row An array of isl/ScopLib integers.
 /// @param Space An isl space object, describing how to spilt the dimensions.
 ///
@@ -613,10 +613,10 @@ isl_constraint *constraintFromMatrixRowF
 }
 
-/// @brief Create an isl map from a OpenScop matrix.
+/// @brief Create an isl map from a ScopLib matrix.
 ///
@@ -613,10 +613,10 @@ isl_constraint *constraintFromMatrixRowF
 ///
-/// @param m The OpenScop matrix to translate.
-/// @param Space The dimensions that are contained in the OpenScop matrix.
+/// @param m The ScopLib matrix to translate.
+/// @param Space The dimensions that are contained in the ScopLib matrix.
 ///
 /// @return An isl map representing m.

Modified: polly/trunk/lib/Makefile
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Makefile?rev=206026&r1=206025&r2=206026&view=diff
==============================================================================